@@ -25,13 +25,14 @@
  *************************************************************************
  */
 
+#ifdef DOT11_N_SUPPORT
+
 #include "rt_config.h"
 
 
 
 #define BA_ORI_INIT_SEQ		(pEntry->TxSeq[TID]) //1			// inital sequence number of BA session
 
-#define MAX_TID_NUM		(15)
 #define ORI_SESSION_MAX_RETRY	8
 #define ORI_BA_SESSION_TIMEOUT	(2000)	// ms
 #define REC_BA_SESSION_IDLE_TIMEOUT	(1000)	// ms
@@ -437,9 +438,9 @@ void ba_flush_reordering_timeout_mpdus(
 		 &&(pBAEntry->list.qlen > 1)
 		)
 	{
-		printk("timeout[%d] (%lx-%lx = %d > %d): %x, flush all!\n ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
+		DBGPRINT(RT_DEBUG_TRACE,("timeout[%d] (%08lx-%08lx = %d > %d): %x, flush all!\n ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
 			   (int)((long) Now32 - (long)(pBAEntry->LastIndSeqAtTimer)), MAX_REORDERING_PACKET_TIMEOUT,
-			   pBAEntry->LastIndSeq);
+			   pBAEntry->LastIndSeq));
 		ba_refresh_reordering_mpdus(pAd, pBAEntry);
 		pBAEntry->LastIndSeqAtTimer = Now32;
 	}
@@ -448,9 +449,9 @@ void ba_flush_reordering_timeout_mpdus(
 		&& (pBAEntry->list.qlen > 0)
 	   )
 		{
-		printk("timeout[%d] (%lx-%lx = %d > %d): %x, ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
-		   (int)((long) Now32 - (long)(pBAEntry->LastIndSeqAtTimer)), REORDERING_PACKET_TIMEOUT,
-		   pBAEntry->LastIndSeq);
+//		printk("timeout[%d] (%lx-%lx = %d > %d): %x, ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
+//			   (int)((long) Now32 - (long)(pBAEntry->LastIndSeqAtTimer)), REORDERING_PACKET_TIMEOUT,
+//			   pBAEntry->LastIndSeq);
     		//
 		// force LastIndSeq to shift to LastIndSeq+1
     		// 
@@ -467,7 +468,7 @@ void ba_flush_reordering_timeout_mpdus(
     			pBAEntry->LastIndSeq = Sequence;
     		}
 
-		printk("%x, flush one!\n", pBAEntry->LastIndSeq);
+		//printk("%x, flush one!\n", pBAEntry->LastIndSeq);
 
 	}
 #if 0
@@ -476,9 +477,9 @@ void ba_flush_reordering_timeout_mpdus(
 			  (pBAEntry->list.qlen > 1))
 			)
 		{
-		printk("timeout[%d] (%lx-%lx = %d > %d): %x\n ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
+		DBGPRINT(RT_DEBUG_TRACE,("timeout[%d] (%lx-%lx = %d > %d): %x\n ", pBAEntry->list.qlen, Now32, (pBAEntry->LastIndSeqAtTimer), 
 			   (int)((long) Now32 - (long)(pBAEntry->LastIndSeqAtTimer)), MAX_REORDERING_PACKET_TIMEOUT,
-			   pBAEntry->LastIndSeq);
+			   pBAEntry->LastIndSeq));
 		ba_refresh_reordering_mpdus(pAd, pBAEntry);
 			pBAEntry->LastIndSeqAtTimer = Now32;
 				}
@@ -513,6 +514,8 @@ VOID BAOriSessionSetUp(
 
 	if ((pEntry->BADeclineBitmap & (1<<TID)) && (isForced == FALSE))
 	{
+		// try again after 3 secs
+		DelayTime = 3000; 
 //		printk("DeCline BA from Peer\n");
 //		return;
 	}
@@ -607,6 +610,7 @@ VOID BAOriSessionAdd(
 			return;
 		}
 
+
 #ifdef CONFIG_STA_SUPPORT
 		IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 			BarHeaderInit(pAd, &FrameBar, pAd->MacTab.Content[pBAEntry->Wcid].Addr, pAd->CurrentAddress);
@@ -705,6 +709,8 @@ BOOLEAN BARecSessionAdd(
 		pEntry->RXBAbitmap |= (1<<TID);
 		pEntry->BARecWcidArray[TID] = Idx;
 
+		pEntry->BADeclineBitmap &= ~(1<<TID);
+
 		// Set BA session mask in WCID table.
 		RT28XX_ADD_BA_SESSION_TO_ASIC(pAd, pEntry->Aid, TID);
 
@@ -1040,7 +1046,7 @@ VOID BASessionTearDownALL(
 {
 	int i;
 
-	for (i=0; i<=MAX_TID_NUM; i++)
+	for (i=0; i<NUM_OF_TID; i++)
 	{
 		BAOriSessionTearDown(pAd, Wcid, i, FALSE, FALSE);
 		BARecSessionTearDown(pAd, Wcid, i, FALSE);
@@ -1226,7 +1232,17 @@ VOID PeerAddBAReqAction(
 	// 2-1. Prepare ADDBA Response frame.
 #ifdef CONFIG_STA_SUPPORT
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
-		ActHeaderInit(pAd, &ADDframe.Hdr, pAd->CommonCfg.Bssid, pAd->CurrentAddress, pAddr);
+	{
+		if (ADHOC_ON(pAd))
+			ActHeaderInit(pAd, &ADDframe.Hdr, pAddr, pAd->CurrentAddress, pAd->CommonCfg.Bssid);
+		else
+#ifdef QOS_DLS_SUPPORT
+		if (pAd->MacTab.Content[Elem->Wcid].ValidAsDls)
+			ActHeaderInit(pAd, &ADDframe.Hdr, pAddr, pAd->CurrentAddress, pAd->CommonCfg.Bssid);
+		else
+#endif // QOS_DLS_SUPPORT //
+			ActHeaderInit(pAd, &ADDframe.Hdr, pAd->CommonCfg.Bssid, pAd->CurrentAddress, pAddr);
+	}
 #endif // CONFIG_STA_SUPPORT //
 	ADDframe.Category = CATEGORY_BA;
 	ADDframe.Action = ADDBA_RESP;
@@ -1726,7 +1742,7 @@ VOID Indicate_AMPDU_Packet(
 	// 
 	else if (Sequence == pBAEntry->LastIndSeq)
 	{
-		DBGPRINT(RT_DEBUG_INFO, ("Duplicated receive pHeader->Sequence = 0x%x ,LastIndSeq = 0x%x. drop \n" , Sequence, pBAEntry->LastIndSeq));
+		
 		// drop and release packet
 		pBAEntry->nDropPacket++;
 		RELEASE_NDIS_PACKET(pAd, pRxBlk->pRxPacket, NDIS_STATUS_FAILURE);
@@ -1736,7 +1752,7 @@ VOID Indicate_AMPDU_Packet(
 	// 
 	else if (SEQ_SMALLER(Sequence, pBAEntry->LastIndSeq, MAXSEQ))
 	{
-		DBGPRINT(RT_DEBUG_INFO, ("Rcv old pHeader->Sequence = 0x%x ,LastIndSeq = 0x%x. drop \n" , Sequence, pBAEntry->LastIndSeq));
+		
 		// drop and release packet
 		pBAEntry->nDropPacket++;
 		RELEASE_NDIS_PACKET(pAd, pRxBlk->pRxPacket, NDIS_STATUS_FAILURE);
@@ -1759,8 +1775,7 @@ VOID Indicate_AMPDU_Packet(
 #else
 		LONG WinStartSeq, TmpSeq;
 
-		DBGPRINT(RT_DEBUG_INFO, ("%lu: Refresh. Sequence=0x%x, #RxPkt = %d.  LastIndSeq  = 0x%x.\n", Now32, Sequence, pBAEntry->list.qlen, pBAEntry->LastIndSeq));
-
+		
 		TmpSeq = Sequence - (pBAEntry->BAWinSize) -1;
 		if (TmpSeq < 0)
 		{
@@ -1782,3 +1797,6 @@ VOID Indicate_AMPDU_Packet(
 #endif
 	}
 }
+
+#endif // DOT11_N_SUPPORT //
+
