@@ -198,7 +198,7 @@ NDIS_STATUS MiniportMMRequestUnlock(
 	TXWI_STRUC		TXWI;
 	ULONG	SW_TX_IDX; 
 	PTXD_STRUC		pTxD;
- 
+
 	QueIdx = 3;
 	ASSERT(Length <= MGMT_DMA_BUFFER_SIZE);
 
@@ -237,7 +237,7 @@ NDIS_STATUS MiniportMMRequestUnlock(
 				DBGPRINT(RT_DEBUG_WARN, ("MiniportMMRequest (error:: can't allocate NDIS PACKET)\n"));
 				break;
 			}
- 
+
 			Status = MlmeHardTransmit(pAd, QueIdx, pPacket);
 			if (Status != NDIS_STATUS_SUCCESS)
 				RTMPFreeNdisPacket(pAd, pPacket);
@@ -282,14 +282,10 @@ NDIS_STATUS MiniportMMRequestUnlock(
 */
 NDIS_STATUS MlmeHardTransmit(
 	IN	PRTMP_ADAPTER	pAd,
-	IN	UCHAR	QueIdx,
+	IN	UCHAR			QueIdx,
 	IN	PNDIS_PACKET	pPacket)
 {
-	if ((pAd->CommonCfg.RadarDetect.RDMode != RD_NORMAL_MODE)
-#ifdef CARRIER_DETECTION_SUPPORT
-		||(isCarrierDetectExist(pAd) == TRUE)
-#endif // CARRIER_DETECTION_SUPPORT //
-		)
+	if (pAd->CommonCfg.RadarDetect.RDMode != RD_NORMAL_MODE)
 	{
 		return NDIS_STATUS_FAILURE;
 	}
@@ -321,12 +317,14 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	PHEADER_802_11	pHeader_802_11;
 	BOOLEAN 		bAckRequired, bInsertTimestamp;
 	ULONG			SrcBufPA;
- 	UCHAR			MlmeRate;
+	UCHAR			MlmeRate;
 	ULONG			SwIdx = pAd->TxRing[QueIdx].TxCpuIdx;
 	PTXWI_STRUC 	pFirstTxWI;
- 	ULONG	 FreeNum;
+	ULONG	 FreeNum;
+	MAC_TABLE_ENTRY	*pMacEntry = NULL;
 
- 	RTMP_QueryPacketInfo(pPacket, &PacketInfo, &pSrcBufVA, &SrcBufLen);	 
+
+	RTMP_QueryPacketInfo(pPacket, &PacketInfo, &pSrcBufVA, &SrcBufLen);	
 
 	if (pSrcBufVA == NULL)
 	{
@@ -359,7 +357,7 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	if (pAd->TxRing[QueIdx].Cell[SwIdx].pNdisPacket)
 	{
 		printk("MlmeHardTransmit Error\n");
- 		return NDIS_STATUS_FAILURE;
+		return NDIS_STATUS_FAILURE;
 	}
 
 
@@ -367,7 +365,7 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 	{
 		// outgoing frame always wakeup PHY to prevent frame lost 
- 		if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_DOZE))
+		if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_DOZE))
 			AsicForceWakeup(pAd, TRUE);
 	}
 #endif // CONFIG_STA_SUPPORT //
@@ -382,7 +380,13 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	{
 		MlmeRate = pAd->CommonCfg.MlmeRate;
 	}
-	
+
+	if ((pHeader_802_11->FC.Type == BTYPE_DATA) &&
+		(pHeader_802_11->FC.SubType == SUBTYPE_QOS_NULL))
+	{
+		pMacEntry = MacTableLookup(pAd, pHeader_802_11->Addr1);
+	}
+
 	// Verify Mlme rate for a / g bands.	
 	if ((pAd->LatchRfRegs.Channel > 14) && (MlmeRate < RATE_6)) // 11A band
 		MlmeRate = RATE_6;
@@ -392,14 +396,12 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	// Snice it's been set to 0 while on MgtMacHeaderInit
 	// By the way this will cause frame to be send on PWR_SAVE failed.
 	// 
-	// pHeader_802_11->FC.PwrMgmt = 0; // (pAd->StaCfg.Psm == PWR_SAVE);
 	//
 	// In WMM-UAPSD, mlme frame should be set psm as power saving but probe request frame
 #ifdef CONFIG_STA_SUPPORT
     // Data-Null packets alse pass through MMRequest in RT2860, however, we hope control the psm bit to pass APSD
-	if ((pHeader_802_11->FC.Type != BTYPE_DATA) || (pAd->OpMode == OPMODE_AP))        
+	if (pHeader_802_11->FC.Type != BTYPE_DATA)
     {
-#endif // CONFIG_STA_SUPPORT //    
     	if ((pHeader_802_11->FC.SubType == SUBTYPE_PROBE_REQ) || !(pAd->CommonCfg.bAPSDCapable && pAd->CommonCfg.APEdcaParm.bAPSDCapable))
     	{
     		pHeader_802_11->FC.PwrMgmt = PWR_ACTIVE;
@@ -408,7 +410,6 @@ NDIS_STATUS MlmeHardTransmitTxRing(
     	{
     		pHeader_802_11->FC.PwrMgmt = pAd->CommonCfg.bAPSDForcePowerSave;
     	}
-#ifdef CONFIG_STA_SUPPORT        
     }
 #endif // CONFIG_STA_SUPPORT //
 	
@@ -444,7 +445,7 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 		&& (pAd->CommonCfg.RadarDetect.RDMode != RD_NORMAL_MODE))
 	{
 		DBGPRINT(RT_DEBUG_ERROR,("MlmeHardTransmit --> radar detect not in normal mode !!!\n"));
- 		return (NDIS_STATUS_FAILURE);
+		return (NDIS_STATUS_FAILURE);
 	}
 
 #ifdef RT_BIG_ENDIAN
@@ -460,10 +461,23 @@ NDIS_STATUS MlmeHardTransmitTxRing(
 	// For inter-frame gap, the number is for this frame and next frame
 	// For MLME rate, we will fix as 2Mb to match other vendor's implement
 	
-	// management frame doesn't need encryption. so use RESERVED_WCID no matter u are sending to specific wcid or not.
+// management frame doesn't need encryption. so use RESERVED_WCID no matter u are sending to specific wcid or not.
 	// Only beacon use Nseq=TRUE. So here we use Nseq=FALSE.
-	RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE, bInsertTimestamp, FALSE, bAckRequired, FALSE, 
+	if (pMacEntry == NULL)
+	{
+		RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE, bInsertTimestamp, FALSE, bAckRequired, FALSE, 
 		0, RESERVED_WCID, (SrcBufLen - TXWI_SIZE), PID_MGMT, 0,  (UCHAR)pAd->CommonCfg.MlmeTransmit.field.MCS, IFS_BACKOFF, FALSE, &pAd->CommonCfg.MlmeTransmit);
+	}
+	else
+	{
+		RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE,
+					bInsertTimestamp, FALSE, bAckRequired, FALSE,
+					0, pMacEntry->Aid, (SrcBufLen - TXWI_SIZE),
+					pMacEntry->MaxHTPhyMode.field.MCS, 0,
+					(UCHAR)pMacEntry->MaxHTPhyMode.field.MCS,
+					IFS_BACKOFF, FALSE, &pMacEntry->MaxHTPhyMode);
+	}
+
 	pAd->TxRing[QueIdx].Cell[SwIdx].pNdisPacket = pPacket;
 	pAd->TxRing[QueIdx].Cell[SwIdx].pNextNdisPacket = NULL;
 #ifdef RT_BIG_ENDIAN
@@ -510,9 +524,10 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 	BOOLEAN 		bAckRequired, bInsertTimestamp;
 	UCHAR			MlmeRate;
 	PTXWI_STRUC 	pFirstTxWI;
+	MAC_TABLE_ENTRY	*pMacEntry = NULL;
 
 	RTMP_QueryPacketInfo(pPacket, &PacketInfo, &pSrcBufVA, &SrcBufLen);	
-	RTMP_SEM_LOCK(&pAd->MgmtRingLock);
+		RTMP_SEM_LOCK(&pAd->MgmtRingLock);
 
 
 	if (pSrcBufVA == NULL)
@@ -524,6 +539,7 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 #ifdef CONFIG_STA_SUPPORT
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 	{
+		// outgoing frame always wakeup PHY to prevent frame lost 
 		if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_DOZE))
 			AsicForceWakeup(pAd, TRUE);
 	}
@@ -540,17 +556,26 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 	{
 		MlmeRate = pAd->CommonCfg.MlmeRate;
 	}
-	
+
 	// Verify Mlme rate for a / g bands.	
 	if ((pAd->LatchRfRegs.Channel > 14) && (MlmeRate < RATE_6)) // 11A band
 		MlmeRate = RATE_6;
 
+	if ((pHeader_802_11->FC.Type == BTYPE_DATA) &&
+		(pHeader_802_11->FC.SubType == SUBTYPE_QOS_NULL))
+	{
+		pMacEntry = MacTableLookup(pAd, pHeader_802_11->Addr1);
+	}
+
 #ifdef CONFIG_STA_SUPPORT
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 	{
 		// Fixed W52 with Activity scan issue in ABG_MIXED and ABGN_MIXED mode.    
-		if (pAd->CommonCfg.PhyMode == PHY_11ABG_MIXED ||
-			pAd->CommonCfg.PhyMode == PHY_11ABGN_MIXED)
+		if (pAd->CommonCfg.PhyMode == PHY_11ABG_MIXED 
+#ifdef DOT11_N_SUPPORT
+			|| pAd->CommonCfg.PhyMode == PHY_11ABGN_MIXED
+#endif // DOT11_N_SUPPORT //
+		)
 		{
 			if (pAd->LatchRfRegs.Channel > 14)
 				pAd->CommonCfg.MlmeTransmit.field.MODE = 1;
@@ -570,25 +595,26 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 	// In WMM-UAPSD, mlme frame should be set psm as power saving but probe request frame
 #ifdef CONFIG_STA_SUPPORT	
     // Data-Null packets alse pass through MMRequest in RT2860, however, we hope control the psm bit to pass APSD    
-	if (((pHeader_802_11->FC.Type != BTYPE_DATA) && (pHeader_802_11->FC.Type != BTYPE_CNTL)) || (pAd->OpMode == OPMODE_AP))
+	if ((pHeader_802_11->FC.Type != BTYPE_DATA) && (pHeader_802_11->FC.Type != BTYPE_CNTL))
 	{
-#endif // CONFIG_STA_SUPPORT //
-		{
-#ifdef CONFIG_STA_SUPPORT			
-			if ((pAd->StaCfg.Psm == PWR_SAVE) &&
-				(pHeader_802_11->FC.SubType == SUBTYPE_ACTION))	
-				pHeader_802_11->FC.PwrMgmt = PWR_SAVE;
-			else
-#endif // CONFIG_STA_SUPPORT //
+		if ((pAd->StaCfg.Psm == PWR_SAVE) &&
+			(pHeader_802_11->FC.SubType == SUBTYPE_ACTION))	
+			pHeader_802_11->FC.PwrMgmt = PWR_SAVE;
+		else
 			pHeader_802_11->FC.PwrMgmt = PWR_ACTIVE;
-		}
-#ifdef CONFIG_STA_SUPPORT 
 	}
 #endif // CONFIG_STA_SUPPORT //
 	
 	bInsertTimestamp = FALSE;
 	if (pHeader_802_11->FC.Type == BTYPE_CNTL) // must be PS-POLL
 	{
+#ifdef CONFIG_STA_SUPPORT
+		//Set PM bit in ps-poll, to fix WLK 1.2  PowerSaveMode_ext failure issue.
+		if ((pAd->OpMode == OPMODE_STA) && (pHeader_802_11->FC.SubType == SUBTYPE_PS_POLL))
+		{
+			pHeader_802_11->FC.PwrMgmt = PWR_SAVE;
+		}
+#endif // CONFIG_STA_SUPPORT //
 		bAckRequired = FALSE;
 	}
 	else // BTYPE_MGMT or BTYPE_DATA(must be NULL frame)
@@ -609,7 +635,6 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 		}
 	}
 
-
 	pHeader_802_11->Sequence = pAd->Sequence++;
 	if (pAd->Sequence >0xfff)
 		pAd->Sequence = 0;
@@ -639,9 +664,22 @@ NDIS_STATUS MlmeHardTransmitMgmtRing(
 	// For inter-frame gap, the number is for this frame and next frame
 	// For MLME rate, we will fix as 2Mb to match other vendor's implement
 	
-	// management frame doesn't need encryption. so use RESERVED_WCID no matter u are sending to specific wcid or not.
-	RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE, bInsertTimestamp, FALSE, bAckRequired, FALSE, 
+// management frame doesn't need encryption. so use RESERVED_WCID no matter u are sending to specific wcid or not.
+	if (pMacEntry == NULL)
+	{
+		RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE, bInsertTimestamp, FALSE, bAckRequired, FALSE, 
 		0, RESERVED_WCID, (SrcBufLen - TXINFO_SIZE - TXWI_SIZE), PID_MGMT, 0,  (UCHAR)pAd->CommonCfg.MlmeTransmit.field.MCS, IFS_BACKOFF, FALSE, &pAd->CommonCfg.MlmeTransmit);
+	}
+	else
+	{
+		RTMPWriteTxWI(pAd, pFirstTxWI, FALSE, FALSE,
+					bInsertTimestamp, FALSE, bAckRequired, FALSE,
+					0, pMacEntry->Aid, (SrcBufLen - TXINFO_SIZE - TXWI_SIZE),
+					pMacEntry->MaxHTPhyMode.field.MCS, 0,
+					(UCHAR)pMacEntry->MaxHTPhyMode.field.MCS,
+					IFS_BACKOFF, FALSE, &pMacEntry->MaxHTPhyMode);
+	}
+
 #ifdef RT_BIG_ENDIAN
 	RTMPWIEndianChange((PUCHAR)pFirstTxWI, TYPE_TXWI);
 #endif
@@ -725,7 +763,9 @@ static UCHAR TxPktClassification(
 	UCHAR			TxFrameType = TX_UNKOWN_FRAME;
 	UCHAR			Wcid;
 	MAC_TABLE_ENTRY	*pMacEntry = NULL;
+#ifdef DOT11_N_SUPPORT
 	BOOLEAN			bHTRate = FALSE;
+#endif // DOT11_N_SUPPORT //
 
 	Wcid = RTMP_GET_PACKET_WCID(pPacket);
 	if (Wcid == MCAST_WCID)
@@ -736,16 +776,17 @@ static UCHAR TxPktClassification(
 	// Handle for unicast packets
 	pMacEntry = &pAd->MacTab.Content[Wcid];
 	if (RTMP_GET_PACKET_LOWRATE(pPacket))
-	{	// It's a specific packet need to force low rate, i.e., bDHCPFrame, bEAPOLFrame
+	{	// It's a specific packet need to force low rate, i.e., bDHCPFrame, bEAPOLFrame, bWAIFrame
 		TxFrameType = TX_LEGACY_FRAME;
 	}
+#ifdef DOT11_N_SUPPORT
 	else if (IS_HT_RATE(pMacEntry))
 	{	// it's a 11n capable packet
 
 		// Depends on HTPhyMode to check if the peer support the HTRate transmission.
 		// 	Currently didn't support A-MSDU embedded in A-MPDU
 		bHTRate = TRUE;
-		if (RTMP_GET_PACKET_MOREDATA(pPacket))
+		if (RTMP_GET_PACKET_MOREDATA(pPacket) || (pMacEntry->PsMode == PWR_SAVE))
 			TxFrameType = TX_LEGACY_FRAME;
 #ifdef UAPSD_AP_SUPPORT
 		else if (RTMP_GET_PACKET_EOSP(pPacket))
@@ -758,6 +799,7 @@ static UCHAR TxPktClassification(
 		else
 			TxFrameType = TX_LEGACY_FRAME;
 	}
+#endif // DOT11_N_SUPPORT //
 	else 
 	{	// it's a legacy b/g packet.
 		if ((CLIENT_STATUS_TEST_FLAG(pMacEntry, fCLIENT_STATUS_AGGREGATION_CAPABLE) && pAd->CommonCfg.bAggregationCapable) &&
@@ -773,7 +815,7 @@ static UCHAR TxPktClassification(
 	}
 
 	// Currently, our fragment only support when a unicast packet send as NOT-ARALINK, NOT-AMSDU and NOT-AMPDU.
-	if ((RTMP_GET_PACKET_FRAGMENTS(pPacket) > 1) && (TxFrameType == TX_LEGACY_FRAME) /*&& (bHTRate == FALSE)*/)
+	if ((RTMP_GET_PACKET_FRAGMENTS(pPacket) > 1) && (TxFrameType == TX_LEGACY_FRAME))
 		TxFrameType = TX_FRAG_FRAME;
 
 	return TxFrameType;
@@ -804,11 +846,20 @@ BOOLEAN RTMP_FillTxBlkInfo(
 	// Default to clear this flag
 	TX_BLK_CLEAR_FLAG(pTxBlk, fTX_bForceNonQoS);
 	
+	
 	if (pTxBlk->Wcid == MCAST_WCID)
 	{
 		pTxBlk->pMacEntry = NULL;
-		pTxBlk->pTransmit = &pAd->MacTab.Content[MCAST_WCID].HTPhyMode;
-		
+		{
+#ifdef MCAST_RATE_SPECIFIC
+			PUCHAR pDA = GET_OS_PKT_DATAPTR(pPacket);
+			if (((*pDA & 0x01) == 0x01) && (*pDA != 0xff))
+				pTxBlk->pTransmit = &pAd->CommonCfg.MCastPhyMode;
+			else
+#endif // MCAST_RATE_SPECIFIC //
+				pTxBlk->pTransmit = &pAd->MacTab.Content[MCAST_WCID].HTPhyMode;
+		}
+
 		TX_BLK_CLEAR_FLAG(pTxBlk, fTX_bAckRequired);	// AckRequired = FALSE, when broadcast packet in Adhoc mode.
 		//TX_BLK_SET_FLAG(pTxBlk, fTX_bForceLowRate);
 		TX_BLK_CLEAR_FLAG(pTxBlk, fTX_bAllowFrag);
@@ -817,6 +868,7 @@ BOOLEAN RTMP_FillTxBlkInfo(
 		{
 			TX_BLK_SET_FLAG(pTxBlk, fTX_bMoreData);
 		}	
+		
 	}
 	else
 	{
@@ -825,19 +877,22 @@ BOOLEAN RTMP_FillTxBlkInfo(
 
 		pMacEntry = pTxBlk->pMacEntry;
 		
+		
 		// For all unicast packets, need Ack unless the Ack Policy is not set as NORMAL_ACK.
 		if (pAd->CommonCfg.AckPolicy[pTxBlk->QueIdx] != NORMAL_ACK)
 			TX_BLK_CLEAR_FLAG(pTxBlk, fTX_bAckRequired);
 		else
 			TX_BLK_SET_FLAG(pTxBlk, fTX_bAckRequired);
+
 		{
 
 #ifdef CONFIG_STA_SUPPORT
 			IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 			{
+
 				// If support WMM, enable it.
 				if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_WMM_INUSED))
-					TX_BLK_SET_FLAG(pTxBlk, fTX_bWMM);		
+					TX_BLK_SET_FLAG(pTxBlk, fTX_bWMM);
 			}
 #endif // CONFIG_STA_SUPPORT //
 		}
@@ -846,9 +901,9 @@ BOOLEAN RTMP_FillTxBlkInfo(
 		{
 			if ( (RTMP_GET_PACKET_LOWRATE(pPacket)) ||
                 ((pAd->OpMode == OPMODE_AP) && (pMacEntry->MaxHTPhyMode.field.MODE == MODE_CCK) && (pMacEntry->MaxHTPhyMode.field.MCS == RATE_1)))
-			{	// Specific packet, i.e., bDHCPFrame, bEAPOLFrame, need force low rate.
+			{	// Specific packet, i.e., bDHCPFrame, bEAPOLFrame, bWAIFrame, need force low rate.
 				pTxBlk->pTransmit = &pAd->MacTab.Content[MCAST_WCID].HTPhyMode;
-
+#ifdef DOT11_N_SUPPORT
 				// Modify the WMM bit for ICV issue. If we have a packet with EOSP field need to set as 1, how to handle it???
 				if (IS_HT_STA(pTxBlk->pMacEntry) && 
 					(CLIENT_STATUS_TEST_FLAG(pMacEntry, fCLIENT_STATUS_RALINK_CHIPSET)) &&
@@ -857,13 +912,16 @@ BOOLEAN RTMP_FillTxBlkInfo(
 					TX_BLK_CLEAR_FLAG(pTxBlk, fTX_bWMM);
 					TX_BLK_SET_FLAG(pTxBlk, fTX_bForceNonQoS);
 				}
+#endif // DOT11_N_SUPPORT //
 			}
 			
+#ifdef DOT11_N_SUPPORT	
 			if ( (IS_HT_RATE(pMacEntry) == FALSE) && 
 				(CLIENT_STATUS_TEST_FLAG(pMacEntry, fCLIENT_STATUS_PIGGYBACK_CAPABLE)))
 			{	// Currently piggy-back only support when peer is operate in b/g mode.
 				TX_BLK_SET_FLAG(pTxBlk, fTX_bPiggyBack);
 			}
+#endif // DOT11_N_SUPPORT //
 
 			if (RTMP_GET_PACKET_MOREDATA(pPacket))
 			{
@@ -902,7 +960,9 @@ BOOLEAN CanDoAggregateTransmit(
 	if (RTMP_GET_PACKET_WCID(pPacket) == MCAST_WCID)
 		return FALSE;
 
-	if (RTMP_GET_PACKET_DHCP(pPacket) || RTMP_GET_PACKET_EAPOL(pPacket))
+	if (RTMP_GET_PACKET_DHCP(pPacket) || 
+		RTMP_GET_PACKET_EAPOL(pPacket) || 
+		RTMP_GET_PACKET_WAI(pPacket))
 		return FALSE;
 	
 	if ((pTxBlk->TxFrameType == TX_AMSDU_FRAME) &&
@@ -972,8 +1032,6 @@ VOID RTMPDeQueuePacket(
 	RtmpDiagStruct	*pDiagStruct = &pAd->DiagStruct;
 #endif
 
-	DBGPRINT(RT_DEBUG_INFO,("RTMPDeQueuePacket (Tx:%d)--> \n", Max_Tx_Packets));
-
 
 	if (QIdx == NUM_OF_TX_RING)
 	{
@@ -984,8 +1042,7 @@ VOID RTMPDeQueuePacket(
 	{
 		sQIdx = eQIdx = QIdx;
 	}
-
-	DBGPRINT(RT_DEBUG_INFO, ("RTMPDeQueuePacket (QueIdx:%d-%d)--> \n", sQIdx, eQIdx));
+	
 	for (QueIdx=sQIdx; QueIdx <= eQIdx; QueIdx++)
 	{
 		Count=0;
@@ -1012,7 +1069,6 @@ VOID RTMPDeQueuePacket(
 				break;
 			
 			DEQUEUE_LOCK(&pAd->irq_lock, bIntContext, IrqFlags);
-			
 			if (&pAd->TxSwQueue[QueIdx] == NULL)
 			{
 #ifdef DBG_DIAGNOSE
@@ -1069,12 +1125,6 @@ VOID RTMPDeQueuePacket(
 			if (!hasTxDesc)
 			{
 				pAd->PrivateInfo.TxRingFullCnt++;
-				DBGPRINT(RT_DEBUG_LOUD, ("TxRing(%d) full, SwQueue Len = %lu, packet required frag =%d!\n", 
-								QueIdx, pAd->TxSwQueue[QueIdx].Number, RTMP_GET_PACKET_FRAGMENTS(pPacket)));
-#ifdef RT2860
-				DBGPRINT(RT_DEBUG_INFO,("DeqPkt -> Not enough free TxD[%d] (TX_CTX_IDX=%u, TxSwFreeIdx=%u)!!!\n",
-								QueIdx, pAd->TxRing[QueIdx].TxCpuIdx, pAd->TxRing[QueIdx].TxSwFreeIdx));
-#endif // RT2860 //
 
 				DEQUEUE_UNLOCK(&pAd->irq_lock, bIntContext, IrqFlags);
 				
@@ -1286,13 +1336,16 @@ VOID RTMPWriteTxWI(
 	
 	pTxWI->NSEQ = NSeq;
 	// John tune the performace with Intel Client in 20 MHz performance
-
+#ifdef DOT11_N_SUPPORT
 	BASize = pAd->CommonCfg.TxBASize;
 
 	if( BASize >7 )
 		BASize =7;
-		
-	pTxWI->BAWinSize = BASize;	
+	pTxWI->BAWinSize = BASize;
+	pTxWI->ShortGI = pTransmit->field.ShortGI;
+	pTxWI->STBC = pTransmit->field.STBC;
+#endif // DOT11_N_SUPPORT //
+
 	pTxWI->WirelessCliID = WCID;
 	pTxWI->MPDUtotalByteCount = Length; 
 	pTxWI->PacketId = PID; 
@@ -1303,33 +1356,31 @@ VOID RTMPWriteTxWI(
 	if (pTxWI->BW)
 		pTxWI->BW = (pAd->CommonCfg.AddHTInfo.AddHtInfo.RecomWidth == 0) ? (BW_20) : (pTransmit->field.BW);	
 #endif // DOT11N_DRAFT3 //
-	pTxWI->ShortGI = pTransmit->field.ShortGI;
-	pTxWI->STBC = pTransmit->field.STBC;
 	
 	pTxWI->MCS = pTransmit->field.MCS;
 	pTxWI->PHYMODE = pTransmit->field.MODE;
 	pTxWI->CFACK = CfAck;
 
-
+#ifdef DOT11_N_SUPPORT
 	if (pMac)
 	{		
-        if (pAd->CommonCfg.bMIMOPSEnable)
-        {
-    		if ((pMac->MmpsMode == MMPS_DYNAMIC) && (pTransmit->field.MCS > 7))
+		if (pAd->CommonCfg.bMIMOPSEnable)
 		{
-			// Dynamic MIMO Power Save Mode
-			pTxWI->MIMOps = 1;
-		} 
-		else if (pMac->MmpsMode == MMPS_STATIC)
-		{
-			// Static MIMO Power Save Mode
-			if (pTransmit->field.MODE >= MODE_HTMIX && pTransmit->field.MCS > 7)
-			{			
-				pTxWI->MCS = 7;
-				pTxWI->MIMOps = 0;
+			if ((pMac->MmpsMode == MMPS_DYNAMIC) && (pTransmit->field.MCS > 7))
+			{
+				// Dynamic MIMO Power Save Mode
+				pTxWI->MIMOps = 1;
+			} 
+			else if (pMac->MmpsMode == MMPS_STATIC)
+			{
+				// Static MIMO Power Save Mode
+				if (pTransmit->field.MODE >= MODE_HTMIX && pTransmit->field.MCS > 7)
+				{			
+					pTxWI->MCS = 7;
+					pTxWI->MIMOps = 0;
+				}
 			}
 		}
-        }
 		//pTxWI->MIMOps = (pMac->PsMode == PWR_MMPS)? 1:0;
 		if (pMac->bIAmBadAtheros && (pMac->WepStatus != Ndis802_11WEPDisabled))
 		{
@@ -1337,9 +1388,10 @@ VOID RTMPWriteTxWI(
 		}
 		else 
 		{
-		pTxWI->MpduDensity = pMac->MpduDensity;
-	}
+			pTxWI->MpduDensity = pMac->MpduDensity;
+		}
 	}
+#endif // DOT11_N_SUPPORT //
 
 	pTxWI->PacketId = pTxWI->MCS;
 	NdisMoveMemory(pOutTxWI, &TxWI, sizeof(TXWI_STRUC));
@@ -1353,15 +1405,17 @@ VOID RTMPWriteTxWI_Data(
 {
 	HTTRANSMIT_SETTING	*pTransmit;
 	PMAC_TABLE_ENTRY	pMacEntry;
+#ifdef DOT11_N_SUPPORT
 	UCHAR				BASize;
-	//BOOLEAN				bAutoRate;
-	//UCHAR				fixed_tx_mode;
+#endif // DOT11_N_SUPPORT //
+
 
 	ASSERT(pTxWI);
 
 	pTransmit = pTxBlk->pTransmit;
 	pMacEntry = pTxBlk->pMacEntry;
 
+
 	//
 	// Always use Long preamble before verifiation short preamble functionality works well.
 	// Todo: remove the following line if short preamble functionality works
@@ -1370,10 +1424,31 @@ VOID RTMPWriteTxWI_Data(
 	NdisZeroMemory(pTxWI, TXWI_SIZE);
 	
 	pTxWI->FRAG		= TX_BLK_TEST_FLAG(pTxBlk, fTX_bAllowFrag);
-
-	pTxWI->AMPDU	= ((pTxBlk->TxFrameType == TX_AMPDU_FRAME) ? TRUE : FALSE);
 	pTxWI->ACK		= TX_BLK_TEST_FLAG(pTxBlk, fTX_bAckRequired);
 	pTxWI->txop		= pTxBlk->FrameGap;
+	
+#ifdef CONFIG_STA_SUPPORT
+#ifdef QOS_DLS_SUPPORT
+	if (pMacEntry &&		
+		(pAd->StaCfg.BssType == BSS_INFRA) &&		
+		(pMacEntry->ValidAsDls == TRUE))
+		pTxWI->WirelessCliID = BSSID_WCID;
+	else
+#endif // QOS_DLS_SUPPORT //
+#endif // CONFIG_STA_SUPPORT //
+		pTxWI->WirelessCliID		= pTxBlk->Wcid;
+
+	pTxWI->MPDUtotalByteCount	= pTxBlk->MpduHeaderLen + pTxBlk->SrcBufLen; 
+	pTxWI->CFACK				= TX_BLK_TEST_FLAG(pTxBlk, fTX_bPiggyBack);
+
+	// If CCK or OFDM, BW must be 20
+	pTxWI->BW = (pTransmit->field.MODE <= MODE_OFDM) ? (BW_20) : (pTransmit->field.BW);
+#ifdef DOT11_N_SUPPORT
+#ifdef DOT11N_DRAFT3
+	if (pTxWI->BW)
+		pTxWI->BW = (pAd->CommonCfg.AddHTInfo.AddHtInfo.RecomWidth == 0) ? (BW_20) : (pTransmit->field.BW);	
+#endif // DOT11N_DRAFT3 //
+	pTxWI->AMPDU	= ((pTxBlk->TxFrameType == TX_AMPDU_FRAME) ? TRUE : FALSE);
 
 	// John tune the performace with Intel Client in 20 MHz performance
 	BASize = pAd->CommonCfg.TxBASize;
@@ -1386,33 +1461,15 @@ VOID RTMPWriteTxWI_Data(
 	}
 
 	pTxWI->TxBF = pTransmit->field.TxBF;
-
-	pTxWI->BAWinSize			= BASize;	
-#ifdef CONFIG_STA_SUPPORT
-#ifdef QOS_DLS_SUPPORT
-	if (pMacEntry &&		
-		(pAd->StaCfg.BssType == BSS_INFRA) &&		
-		(pMacEntry->ValidAsDls == TRUE))
-		pTxWI->WirelessCliID = BSSID_WCID;
-	else
-#endif // QOS_DLS_SUPPORT //
-#endif // CONFIG_STA_SUPPORT //
-	pTxWI->WirelessCliID		= pTxBlk->Wcid;
-	pTxWI->MPDUtotalByteCount	= pTxBlk->MpduHeaderLen + pTxBlk->SrcBufLen; 
-	pTxWI->CFACK				= TX_BLK_TEST_FLAG(pTxBlk, fTX_bPiggyBack);
-
-	// If CCK or OFDM, BW must be 20
-	pTxWI->BW = (pTransmit->field.MODE <= MODE_OFDM) ? (BW_20) : (pTransmit->field.BW);
-#ifdef DOT11N_DRAFT3
-	if (pTxWI->BW)
-		pTxWI->BW = (pAd->CommonCfg.AddHTInfo.AddHtInfo.RecomWidth == 0) ? (BW_20) : (pTransmit->field.BW);	
-#endif // DOT11N_DRAFT3 //
+	pTxWI->BAWinSize = BASize;
 	pTxWI->ShortGI = pTransmit->field.ShortGI;
 	pTxWI->STBC = pTransmit->field.STBC;
-	
+#endif // DOT11_N_SUPPORT //
+
 	pTxWI->MCS = pTransmit->field.MCS;
 	pTxWI->PHYMODE = pTransmit->field.MODE;
 
+#ifdef DOT11_N_SUPPORT
 	if (pMacEntry)
 	{		
 		if ((pMacEntry->MmpsMode == MMPS_DYNAMIC) && (pTransmit->field.MCS > 7))
@@ -1436,10 +1493,11 @@ VOID RTMPWriteTxWI_Data(
 		}
 		else 
 		{
-		pTxWI->MpduDensity = pMacEntry->MpduDensity;
+			pTxWI->MpduDensity = pMacEntry->MpduDensity;
+		}
 	}
-	}
-	
+#endif // DOT11_N_SUPPORT //
+
 #ifdef DBG_DIAGNOSE
 		if (pTxBlk->QueIdx== 0)
 		{
@@ -1482,6 +1540,8 @@ VOID RTMPWriteTxWI_Cache(
 		// set PID for TxRateSwitching
 		pTxWI->PacketId = pTransmit->field.MCS;
 	}
+
+#ifdef DOT11_N_SUPPORT
 	pTxWI->AMPDU = ((pMacEntry->NoBADataCountDown == 0) ? TRUE: FALSE);
 	pTxWI->MIMOps = 0;
 
@@ -1490,8 +1550,8 @@ VOID RTMPWriteTxWI_Cache(
 		pTxWI->BW = (pAd->CommonCfg.AddHTInfo.AddHtInfo.RecomWidth == 0) ? (BW_20) : (pTransmit->field.BW);	
 #endif // DOT11N_DRAFT3 //
 
-    if (pAd->CommonCfg.bMIMOPSEnable)
-    {
+	if (pAd->CommonCfg.bMIMOPSEnable)
+	{
 		// MIMO Power Save Mode
 		if ((pMacEntry->MmpsMode == MMPS_DYNAMIC) && (pTransmit->field.MCS > 7))
 		{
@@ -1507,7 +1567,8 @@ VOID RTMPWriteTxWI_Cache(
 				pTxWI->MIMOps = 0;
 			}
 		}
-    }
+	}
+#endif // DOT11_N_SUPPORT //
 
 #ifdef DBG_DIAGNOSE
 	if (pTxBlk->QueIdx== 0)
@@ -1622,13 +1683,15 @@ BOOLEAN PeerIsAggreOn(
 	
 	if (pMacEntry != NULL && CLIENT_STATUS_TEST_FLAG(pMacEntry, AFlags))
 	{		
-		//if (TxRate >= RATE_6)
+#ifdef DOT11_N_SUPPORT
 		if (pMacEntry->HTPhyMode.field.MODE >= MODE_HTMIX)
 		{			
 			return TRUE;
 		}
+#endif // DOT11_N_SUPPORT //
+
 #ifdef AGGREGATION_SUPPORT
-		else if (TxRate >= RATE_6 && pAd->CommonCfg.bAggregationCapable && (!(OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_WMM_INUSED) && CLIENT_STATUS_TEST_FLAG(pMacEntry, fCLIENT_STATUS_WMM_CAPABLE))))
+		if (TxRate >= RATE_6 && pAd->CommonCfg.bAggregationCapable && (!(OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_WMM_INUSED) && CLIENT_STATUS_TEST_FLAG(pMacEntry, fCLIENT_STATUS_WMM_CAPABLE))))
 		{	// legacy  Ralink Aggregation support
 			return TRUE;
 		}
@@ -1926,7 +1989,7 @@ kick_out:
 #endif // RALINK_ATE //
 	}
 
-	DBGPRINT(RT_DEBUG_LOUD, ("RTMPFreeTXDUponTxDmaDone %d.\n", FREE));
+	
 	return  bReschedule;
 
 }	
@@ -2075,7 +2138,6 @@ VOID	RTMPHandleTBTTInterrupt(
 	{
 		if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_DOZE))
 		{
-			DBGPRINT(RT_DEBUG_INFO, ("RTMPHandleTBTTInterrupt...\n"));
 		}
 	}
 }
@@ -2101,6 +2163,8 @@ VOID	RTMPHandlePreTBTTInterrupt(
 			DBGPRINT(RT_DEBUG_TRACE, ("RTMPHandlePreTBTTInterrupt...\n"));
 		}
 	}
+
+
 }
 
 VOID	RTMPHandleRxCoherentInterrupt(
@@ -2271,13 +2335,6 @@ VOID	RTMPSuspendMsduTransmission(
 {
 	DBGPRINT(RT_DEBUG_TRACE,("SCANNING, suspend MSDU transmission ...\n"));
 
-#ifdef CARRIER_DETECTION_SUPPORT // Roger sync Carrier
-	// no carrier detection when scanning
-	if (pAd->CommonCfg.CarrierDetect.Enable == TRUE)
-	{
-		CarrierDetectionStop(pAd);
-	}
-#endif
 
 	//
 	// Before BSS_SCAN_IN_PROGRESS, we need to keep Current R66 value and
@@ -2312,19 +2369,9 @@ VOID	RTMPSuspendMsduTransmission(
 */
 VOID RTMPResumeMsduTransmission(
 	IN	PRTMP_ADAPTER	pAd)
-{    
+{
 	DBGPRINT(RT_DEBUG_TRACE,("SCAN done, resume MSDU transmission ...\n"));
 
-#ifdef CARRIER_DETECTION_SUPPORT // Roger sync Carrier
-	// no carrier detection when scanning
-	if (pAd->CommonCfg.CarrierDetect.Enable == TRUE)
-	{
-		if (isCarrierDetectExist(pAd))
-			CarrierDetectionStart(pAd, 0);
-		else
-			CarrierDetectionStart(pAd, 1);
-	}
-#endif
 
 	RTMP_BBP_IO_WRITE8_BY_REG_ID(pAd, BBP_R66, pAd->BbpTuning.R66CurrentValue);
 
@@ -2485,56 +2532,6 @@ MAC_TABLE_ENTRY *MacTableLookup(
 	return pEntry;
 }
 
-
-/*
-	==========================================================================
-	Description:
-		This routine reset the entire MAC table. All packets pending in
-		the power-saving queues are freed here.
-	==========================================================================
- */
-VOID STAMacTableReset(
-	IN  PRTMP_ADAPTER  pAd)
-{
-	int         i;
-	USHORT      Reason;
-
-	DBGPRINT(RT_DEBUG_TRACE, ("STAMacTableReset\n"));
-	NdisAcquireSpinLock(&pAd->MacTabLock);
-
-	for (i=1; i<MAX_LEN_OF_MAC_TABLE; i++)
-	{
-		Reason = MAC_WCID_BASE + (i* HW_WCID_ENTRY_SIZE);	
-
-#ifdef RT2860
-		RTMP_IO_WRITE32(pAd, Reason, 0xffffffff);
-		RTMP_IO_WRITE32(pAd, Reason+4, 0xffff);
-#endif // RT2860 //
-
-		if (pAd->MacTab.Content[i].ValidAsCLI == TRUE)
-	    {
-
-			// free resources of BA
-			BASessionTearDownALL(pAd, i);
-
-			pAd->MacTab.Content[i].ValidAsCLI = FALSE;
-
-			Reason = MAC_WCID_BASE + (i* HW_WCID_ENTRY_SIZE);
-
-#ifdef RT2860
-			RTMP_IO_WRITE32(pAd, Reason, 0xffffffff);
-			RTMP_IO_WRITE32(pAd, Reason+4, 0xffff);
-#endif // RT2860 //
-		}
-
-	}
-
-	NdisZeroMemory(&pAd->MacTab, sizeof(MAC_TABLE));
-
-	NdisReleaseSpinLock(&pAd->MacTabLock);
-}
-
-
 MAC_TABLE_ENTRY *MacTableInsertEntry(
 	IN  PRTMP_ADAPTER   pAd, 
 	IN  PUCHAR			pAddr,
@@ -2650,6 +2647,17 @@ MAC_TABLE_ENTRY *MacTableInsertEntry(
 			pEntry->GTKState = REKEY_NEGOTIATING;
 			pEntry->PairwiseKey.KeyLen = 0;
 			pEntry->PairwiseKey.CipherAlg = CIPHER_NONE;
+#ifdef CONFIG_STA_SUPPORT
+			if ((pAd->OpMode == OPMODE_STA) &&
+				(pAd->StaCfg.BssType == BSS_ADHOC))
+				pEntry->PortSecured = WPA_802_1X_PORT_SECURED;
+			else
+#ifdef QOS_DLS_SUPPORT
+			if (pEntry->ValidAsDls == TRUE)
+				pEntry->PortSecured = WPA_802_1X_PORT_SECURED;
+			else 
+#endif //QOS_DLS_SUPPORT
+#endif // CONFIG_STA_SUPPORT //
 			pEntry->PortSecured = WPA_802_1X_PORT_NOT_SECURED;
 			pEntry->PMKID_CacheIdx = ENTRY_NOT_FOUND;
 			COPY_MAC_ADDR(pEntry->Addr, pAddr);
@@ -2660,6 +2668,7 @@ MAC_TABLE_ENTRY *MacTableInsertEntry(
 			pEntry->PsMode = PWR_ACTIVE;
 			pEntry->PsQIdleCount = 0;
 			pEntry->NoDataIdleCount = 0;
+			pEntry->ContinueTxFailCnt = 0;
 			InitializeQueueHeader(&pEntry->PsQueue);
 
 
@@ -2732,8 +2741,10 @@ BOOLEAN MacTableDeleteEntry(
 			// Delete this entry from ASIC on-chip WCID Table
 			RT28XX_STA_ENTRY_MAC_RESET(pAd, wcid);
 
+#ifdef DOT11_N_SUPPORT
 			// free resources of BA
 			BASessionTearDownALL(pAd, pEntry->Aid);
+#endif // DOT11_N_SUPPORT //
 
 
 			pPrevEntry = NULL;
@@ -2766,11 +2777,11 @@ BOOLEAN MacTableDeleteEntry(
 			RT28XX_STA_ENTRY_KEY_DEL(pAd, BSS0, wcid);
 
 
-			if (pEntry->EnqueueEapolStartTimerRunning != EAPOL_START_DISABLE)
-            {                
-                RTMPCancelTimer(&pEntry->EnqueueStartForPSKTimer, &Cancelled);
-                pEntry->EnqueueEapolStartTimerRunning = EAPOL_START_DISABLE;             
-            }
+		if (pEntry->EnqueueEapolStartTimerRunning != EAPOL_START_DISABLE)
+		{                
+			RTMPCancelTimer(&pEntry->EnqueueStartForPSKTimer, &Cancelled);
+			pEntry->EnqueueEapolStartTimerRunning = EAPOL_START_DISABLE;             
+		}
 
 
    			NdisZeroMemory(pEntry, sizeof(MAC_TABLE_ENTRY));
@@ -2788,14 +2799,56 @@ BOOLEAN MacTableDeleteEntry(
 	//Reset operating mode when no Sta.
 	if (pAd->MacTab.Size == 0)
 	{
+#ifdef DOT11_N_SUPPORT
 		pAd->CommonCfg.AddHTInfo.AddHtInfo2.OperaionMode = 0;
-		AsicUpdateProtect(pAd, pAd->CommonCfg.AddHTInfo.AddHtInfo2.OperaionMode, (ALLN_SETPROTECT), TRUE, pAd->MacTab.fAnyStationNonGF);
+#endif // DOT11_N_SUPPORT //
+		AsicUpdateProtect(pAd, 0 /*pAd->CommonCfg.AddHTInfo.AddHtInfo2.OperaionMode*/, (ALLN_SETPROTECT), TRUE, 0 /*pAd->MacTab.fAnyStationNonGF*/);
 	}
 
 	return TRUE;
 }
 
 
+/*
+	==========================================================================
+	Description:
+		This routine reset the entire MAC table. All packets pending in
+		the power-saving queues are freed here.
+	==========================================================================
+ */
+VOID MacTableReset(
+	IN  PRTMP_ADAPTER  pAd)
+{
+	int         i;
+
+	DBGPRINT(RT_DEBUG_TRACE, ("MacTableReset\n"));
+	//NdisAcquireSpinLock(&pAd->MacTabLock);
+
+	for (i=1; i<MAX_LEN_OF_MAC_TABLE; i++)
+	{
+#ifdef RT2860
+		RT28XX_STA_ENTRY_MAC_RESET(pAd, i);
+#endif // RT2860 //
+		if (pAd->MacTab.Content[i].ValidAsCLI == TRUE)
+	   {
+
+#ifdef DOT11_N_SUPPORT
+			// free resources of BA
+			BASessionTearDownALL(pAd, i);
+#endif // DOT11_N_SUPPORT //
+
+			pAd->MacTab.Content[i].ValidAsCLI = FALSE;
+
+
+
+
+			//AsicDelWcidTab(pAd, i);
+		}
+	}
+
+	return;
+}
+
 /*
 	==========================================================================
 	Description:
@@ -2966,7 +3019,7 @@ BOOLEAN RTMPCheckEtherType(
 		*/
 		if (pSrcBuf[0] == 0xAA && pSrcBuf[1] == 0xAA && pSrcBuf[2] == 0x03)
 		{
-			Sniff2BytesFromNdisBuffer(pSrcBuf, 6, &Byte0, &Byte0);
+			Sniff2BytesFromNdisBuffer(pSrcBuf, 6, &Byte0, &Byte1);
 			RTMP_SET_PACKET_LLCSNAP(pPacket, 1);
 			TypeLen = (USHORT)((Byte0 << 8) + Byte1);
 			pSrcBuf += 8; // Skip this LLC/SNAP header
@@ -3123,19 +3176,22 @@ VOID CmmRxnonRalinkFrameIndicate(
 	IN	RX_BLK			*pRxBlk,
 	IN	UCHAR			FromWhichBSSID)
 {
-
+#ifdef DOT11_N_SUPPORT
 	if (RX_BLK_TEST_FLAG(pRxBlk, fRX_AMPDU) && (pAd->CommonCfg.bDisableReordering == 0)) 
 	{
 		Indicate_AMPDU_Packet(pAd, pRxBlk, FromWhichBSSID);
 	} 
 	else 
+#endif // DOT11_N_SUPPORT //
 	{
+#ifdef DOT11_N_SUPPORT
 		if (RX_BLK_TEST_FLAG(pRxBlk, fRX_AMSDU))
 		{  
 			// handle A-MSDU
 			Indicate_AMSDU_Packet(pAd, pRxBlk, FromWhichBSSID);
 		}
 		else
+#endif // DOT11_N_SUPPORT //
 		{						 
 			Indicate_Legacy_Packet(pAd, pRxBlk, FromWhichBSSID);
 		}
