@@ -59,7 +59,7 @@ USHORT RtmpPCI_WriteTxResource(
 
 	// copy TXINFO + TXWI + WLAN Header + LLC into DMA Header Buffer
 	if (pTxBlk->TxFrameType == TX_AMSDU_FRAME)
-	{ 
+	{
 		hwHeaderLen = pTxBlk->MpduHeaderLen - LENGTH_AMSDU_SUBFRAMEHEAD + pTxBlk->HdrPadLen + LENGTH_AMSDU_SUBFRAMEHEAD;
 	}
 	else
@@ -390,7 +390,7 @@ USHORT	RtmpPCI_WriteFragTxResource(
 	
 	pTxD->SDPtr0 = BufBasePaLow;
 	pTxD->SDLen0 = firstDMALen; // include padding
-	pTxD->SDPtr1 = PCI_MAP_SINGLE(pAd, pTxBlk, 0, 1, PCI_DMA_TODEVICE);;
+	pTxD->SDPtr1 = PCI_MAP_SINGLE(pAd, pTxBlk, 0, 1, PCI_DMA_TODEVICE);
 	pTxD->SDLen1 = pTxBlk->SrcBufLen;
 	pTxD->LastSec0 = 0;
 	pTxD->LastSec1 = 1;
@@ -417,7 +417,7 @@ USHORT	RtmpPCI_WriteFragTxResource(
 
 	return RetTxIdx;
 	
-} 
+}
 
 /*
 	Must be run in Interrupt context
@@ -587,7 +587,7 @@ NDIS_STATUS RTMPCheckRxError(
 		if (pHeader == NULL)
 			return(NDIS_STATUS_SUCCESS);
 		
- 		return(NDIS_STATUS_FAILURE);
+		return(NDIS_STATUS_FAILURE);
 	}
 	
 	return(NDIS_STATUS_SUCCESS);
@@ -776,10 +776,6 @@ VOID RT28xxPciAsicRadioOff(
 		RTMP_IO_WRITE32(pAd, WPDMA_GLO_CFG, DmaCfg.word);
 	}
     
-	// Disable for stability. If PCIE Link Control is modified for advance power save, re-covery this code segment.
-    RTMP_IO_WRITE32(pAd, PBF_SYS_CTRL, 0x1280);
-    OPSTATUS_SET_FLAG(pAd, fOP_STATUS_CLKSELECT_40MHZ);    
-    
 	if (Level == DOT11POWERSAVE)
 	{
 		AUTO_WAKEUP_STRUC	AutoWakeupCfg;
@@ -839,9 +835,7 @@ BOOLEAN RT28xxPciAsicRadioOn(
 	{
 	    pAd->Mlme.bPsPollTimerRunning = FALSE;
 		RTMPCancelTimer(&pAd->Mlme.PsPollTimer,	&Cancelled);
-	    // Need to check bPCIclkOffCommand flag. Because sometimes miss RTMPPCIePowerLinkCtrlRestore function before call this RadioOn from
-		// autowakeup interrupt in EeePC.
-		if ((Level == GUIRADIO_OFF) || (Level == GUI_IDLE_POWER_SAVE) || (pAd->bPCIclkOffCommand == TRUE))
+		if ((Level == GUIRADIO_OFF) || (Level == GUI_IDLE_POWER_SAVE))
 		{
 			DBGPRINT(RT_DEBUG_TRACE, ("RT28xxPciAsicRadioOn ()\n"));
 			// 1. Set PCI Link Control in Configuration Space.
@@ -851,16 +845,12 @@ BOOLEAN RT28xxPciAsicRadioOn(
 	}
     
     pAd->bPCIclkOff = FALSE;
-	// Disable for stability. If PCIE Link Control is modified for advance power save, re-covery this code segment.
-   	RTMP_IO_WRITE32(pAd, PBF_SYS_CTRL, 0x1a80);
-    OPSTATUS_SET_FLAG(pAd, fOP_STATUS_CLKSELECT_40MHZ);
     
 	// 2. Send wake up command.
 	AsicSendCommandToMcu(pAd, 0x31, PowerWakeCID, 0x00, 0x00);
     
 	// 2-1. wait command ok.
 	brv = AsicCheckCommanOk(pAd, PowerWakeCID);	
-
     if (brv)
     {
     	//RTMP_IO_WRITE32(pAd, INT_MASK_CSR, (DELAYINTMASK|RxINT));
@@ -1003,7 +993,7 @@ VOID RT28xxPciStaAsicSleepThenAutoWakeup(
         AUTO_WAKEUP_STRUC	AutoWakeupCfg;	
         // we have decided to SLEEP, so at least do it for a BEACON period.	
         if (TbttNumToNextWakeUp == 0)
-            TbttNumToNextWakeUp = 1;
+            TbttNumToNextWakeUp = 1; 
         
         AutoWakeupCfg.word = 0; 
         RTMP_IO_WRITE32(pAd, AUTO_WAKEUP_CFG, AutoWakeupCfg.word);  
@@ -1072,12 +1062,6 @@ VOID  RadioOnExec(
 		RTMPRingCleanUp(pAd, QID_MGMT);
 		RTMPRingCleanUp(pAd, QID_RX);
 
-        
-		// Disable for stability. If PCIE Link Control is modified for advance power save, re-covery this code segment.
-  		// Turn Off PDB clk
-   		RTMP_IO_WRITE32(pAd, PBF_SYS_CTRL, 0x1a80);
-        OPSTATUS_SET_FLAG(pAd, fOP_STATUS_CLKSELECT_40MHZ);
-		
 		// 2. Send wake up command.
 		AsicSendCommandToMcu(pAd, 0x31, PowerWakeCID, 0x00, 0x02);   
 		// 2-1. wait command ok.
@@ -1115,11 +1099,6 @@ VOID  RadioOnExec(
         if (pAd->StaCfg.Psm == PWR_ACTIVE)
         {
     		RTMP_BBP_IO_WRITE8_BY_REG_ID(pAd, BBP_R3, pAd->StaCfg.BBPR3);
-			
-            // Turn clk to 80Mhz.
-            // Disable for stability. If PCIE Link Control is modified for advance power save, re-covery this code segment.
-            RTMP_IO_WRITE32(pAd, PBF_SYS_CTRL, 0xe80);
-            OPSTATUS_CLEAR_FLAG(pAd, fOP_STATUS_CLKSELECT_40MHZ);
         }
 	}
 	else
@@ -1149,7 +1128,7 @@ VOID RT28xxPciMlmeRadioOn(
     	RTMPRingCleanUp(pAd, QID_AC_VO);
     	RTMPRingCleanUp(pAd, QID_HCCA);
     	RTMPRingCleanUp(pAd, QID_MGMT);
-    	RTMPRingCleanUp(pAd, QID_RX);
+    	RTMPRingCleanUp(pAd, QID_RX);		
 
     	// Enable Tx/Rx
     	RTMPEnableRxTx(pAd);
