@@ -1090,7 +1090,9 @@ static VOID StartDFSProcedure(
 {
 	// start DFS procedure
 	pAd->CommonCfg.Channel = Channel;
+#ifdef DOT11_N_SUPPORT
 	N_ChannelCheck(pAd);
+#endif // DOT11_N_SUPPORT //
 	pAd->CommonCfg.RadarDetect.RDMode = RD_SWITCHING_MODE;
 	pAd->CommonCfg.RadarDetect.CSCount = 0;
 }
@@ -1147,8 +1149,7 @@ static BOOLEAN PeerChSwAnnSanity(
 				NdisMoveMemory(&pChSwAnnInfo->ChSwMode, eid_ptr->Octet, 1);
 				NdisMoveMemory(&pChSwAnnInfo->Channel, eid_ptr->Octet + 1, 1);
 				NdisMoveMemory(&pChSwAnnInfo->ChSwCnt, eid_ptr->Octet + 2, 1);
-				DBGPRINT(RT_DEBUG_INFO, ("%s - IE_CHANNEL_SWITCH_ANNOUNCEMENT., ChSwMode=%d NewCh=%d ChSwCnt=%d.\n",
-					__FUNCTION__, pChSwAnnInfo->ChSwMode, pChSwAnnInfo->Channel, pChSwAnnInfo->ChSwCnt));
+				
 				result = TRUE;
                 break;
             
@@ -1218,9 +1219,7 @@ static BOOLEAN PeerMeasureReqSanity(
 				pMeasureReqInfo->MeasureReq.MeasureStartTime = SWAP64(MeasureStartTime);
 				NdisMoveMemory(&MeasureDuration, ptr + 9, 2);
 				pMeasureReqInfo->MeasureReq.MeasureDuration = SWAP16(MeasureDuration);
-				DBGPRINT(RT_DEBUG_INFO, ("%s - IE_MEASUREMENT_REQUEST., ChNum=%d StartTime=%lld Duration=%d\n",
-					__FUNCTION__, pMeasureReqInfo->MeasureReq.ChNum, pMeasureReqInfo->MeasureReq.MeasureStartTime,
-					pMeasureReqInfo->MeasureReq.MeasureDuration));
+				
 				result = TRUE;
 				break;
 
@@ -1312,7 +1311,7 @@ static BOOLEAN PeerMeasureReportSanity(
 					NdisMoveMemory(&pReport->MeasureStartTime, ptr + 1, 8);
 					NdisMoveMemory(&pReport->MeasureDuration, ptr + 9, 2);
 					NdisMoveMemory(&pReport->Map, ptr + 11, 1);
-					DBGPRINT(RT_DEBUG_INFO, ("%s - IE_MEASUREMENT_REPORT., ChNum=%d StartTime=%lld Duration=%d Map=%x.\n", __FUNCTION__, pReport->ChNum, pReport->MeasureStartTime, pReport->MeasureDuration, pReport->Map.word));
+					
 				}
 				else if (pMeasureReportInfo->ReportType == RM_CCA)
 				{
@@ -1322,7 +1321,7 @@ static BOOLEAN PeerMeasureReportSanity(
 					NdisMoveMemory(&pReport->MeasureStartTime, ptr + 1, 8);
 					NdisMoveMemory(&pReport->MeasureDuration, ptr + 9, 2);
 					NdisMoveMemory(&pReport->CCA_Busy_Fraction, ptr + 11, 1);
-					DBGPRINT(RT_DEBUG_INFO, ("%s - IE_MEASUREMENT_REPORT., ChNum=%d StartTime=%lld Duration=%d CCA_Busy_Fraction=%d.\n", __FUNCTION__, pReport->ChNum, pReport->MeasureStartTime, pReport->MeasureDuration, pReport->CCA_Busy_Fraction));
+					
 				}
 				else if (pMeasureReportInfo->ReportType == RM_RPI_HISTOGRAM)
 				{
@@ -1332,7 +1331,6 @@ static BOOLEAN PeerMeasureReportSanity(
 					NdisMoveMemory(&pReport->MeasureStartTime, ptr + 1, 8);
 					NdisMoveMemory(&pReport->MeasureDuration, ptr + 9, 2);
 					NdisMoveMemory(&pReport->RPI_Density, ptr + 11, 8);
-					DBGPRINT(RT_DEBUG_INFO, ("%s - IE_MEASUREMENT_REPORT., ChNum=%d StartTime=%lld Duration=%d.\n", __FUNCTION__, pReport->ChNum, pReport->MeasureStartTime, pReport->MeasureDuration));
 				}
 				result = TRUE;
                 break;
@@ -1477,6 +1475,10 @@ static VOID PeerChSwAnnAction(
 {
 	CH_SW_ANN_INFO ChSwAnnInfo;
 	PFRAME_802_11 pFr = (PFRAME_802_11)Elem->Msg;
+#ifdef CONFIG_STA_SUPPORT
+	UCHAR index = 0, Channel = 0, NewChannel = 0;
+	ULONG Bssidx = 0;
+#endif // CONFIG_STA_SUPPORT //
 
 	NdisZeroMemory(&ChSwAnnInfo, sizeof(CH_SW_ANN_INFO));
 	if (! PeerChSwAnnSanity(pAd, Elem->Msg, Elem->MsgLen, &ChSwAnnInfo))
@@ -1485,12 +1487,55 @@ static VOID PeerChSwAnnAction(
 		return;
 	}
 
-	// ChSwAnn need check.
-	if (DfsRequirementCheck(pAd, ChSwAnnInfo.Channel) == TRUE)
+
+#ifdef CONFIG_STA_SUPPORT
+	if (pAd->OpMode == OPMODE_STA)
 	{
-		NotifyChSwAnnToPeerAPs(pAd, pFr->Hdr.Addr1, pFr->Hdr.Addr2, ChSwAnnInfo.ChSwMode, ChSwAnnInfo.Channel);
-		StartDFSProcedure(pAd, ChSwAnnInfo.Channel, ChSwAnnInfo.ChSwMode);
+		Bssidx = BssTableSearch(&pAd->ScanTab, pFr->Hdr.Addr3, pAd->CommonCfg.Channel);
+		if (Bssidx == BSS_NOT_FOUND)
+		{
+			DBGPRINT(RT_DEBUG_TRACE, ("PeerChSwAnnAction - Bssidx is not found\n"));
+			return;  
+		}
+
+		DBGPRINT(RT_DEBUG_TRACE, ("\n****Bssidx is %d, Channel = %d\n", index, pAd->ScanTab.BssEntry[Bssidx].Channel));
+		hex_dump("SSID",pAd->ScanTab.BssEntry[Bssidx].Bssid ,6);
+
+		Channel = pAd->CommonCfg.Channel;
+		NewChannel = ChSwAnnInfo.Channel;
+
+		if ((pAd->CommonCfg.bIEEE80211H == 1) && (NewChannel != 0) && (Channel != NewChannel))
+		{
+			// Switching to channel 1 can prevent from rescanning the current channel immediately (by auto reconnection).
+			// In addition, clear the MLME queue and the scan table to discard the RX packets and previous scanning results.
+			AsicSwitchChannel(pAd, 1, FALSE);
+			AsicLockChannel(pAd, 1);
+		    LinkDown(pAd, FALSE);
+			MlmeQueueInit(&pAd->Mlme.Queue);
+			BssTableInit(&pAd->ScanTab);
+		    RTMPusecDelay(1000000);		// use delay to prevent STA do reassoc
+					
+			// channel sanity check
+			for (index = 0 ; index < pAd->ChannelListNum; index++)
+			{
+				if (pAd->ChannelList[index].Channel == NewChannel)
+				{
+					pAd->ScanTab.BssEntry[Bssidx].Channel = NewChannel;
+					pAd->CommonCfg.Channel = NewChannel;
+					AsicSwitchChannel(pAd, pAd->CommonCfg.Channel, FALSE);
+					AsicLockChannel(pAd, pAd->CommonCfg.Channel);
+					DBGPRINT(RT_DEBUG_TRACE, ("&&&&&&&&&&&&&&&&PeerChSwAnnAction - STA receive channel switch announcement IE (New Channel =%d)\n", NewChannel));
+					break;
+				}
+			}
+
+			if (index >= pAd->ChannelListNum)
+			{
+				DBGPRINT_ERR(("&&&&&&&&&&&&&&&&&&&&&&&&&&PeerChSwAnnAction(can not find New Channel=%d in ChannelList[%d]\n", pAd->CommonCfg.Channel, pAd->ChannelListNum));
+			}
+		}
 	}
+#endif // CONFIG_STA_SUPPORT //
 
 	return;
 }
