@@ -112,7 +112,7 @@ extern UINT32 CW_MAX_IN_BITS;
 #define RSSI_WEIGHTING                   50
 #define TX_WEIGHTING                     30
 #define RX_WEIGHTING                     20
- 
+
 #define BSS_NOT_FOUND                    0xFFFFFFFF
 
 
@@ -494,7 +494,7 @@ typedef struct {
 //This structure substracts ralink supports from all 802.11n-related features.
 //Features not listed here but contained in 802.11n spec are not supported in rt2860.
 typedef struct {
- #ifdef RT_BIG_ENDIAN
+#ifdef RT_BIG_ENDIAN
 	USHORT	rsv:5;
 	USHORT	AmsduSize:1;	// Max receiving A-MSDU size
 	USHORT	AmsduEnable:1;	// Enable to transmit A-MSDU. Suggest disable. We should use A-MPDU to gain best benifit of 802.11n
@@ -1170,7 +1170,7 @@ typedef struct {
 #ifdef CONFIG_STA_SUPPORT
     WPA_IE_     WpaIE;
     WPA_IE_     RsnIE;
- #ifdef EXT_BUILD_CHANNEL_LIST
+#ifdef EXT_BUILD_CHANNEL_LIST
 	UCHAR		CountryString[3];
 	BOOLEAN		bHasCountryIE;
 #endif // EXT_BUILD_CHANNEL_LIST //
@@ -1197,9 +1197,6 @@ typedef struct _MLME_QUEUE_ELEM {
     UCHAR             Channel;
     UCHAR             Wcid;
     BOOLEAN           Occupied;
-#ifdef MLME_EX
-	USHORT            Idx;
-#endif // MLME_EX //
 } MLME_QUEUE_ELEM, *PMLME_QUEUE_ELEM;
 
 typedef struct _MLME_QUEUE {
@@ -1396,6 +1393,9 @@ typedef struct PACKED _RTMP_TX_RATE_SWITCH
 #define MAC_TABLE_ASSOC_TIMEOUT			5			// unit: sec
 #define MAC_TABLE_FULL(Tab)				((Tab).size == MAX_LEN_OF_MAC_TABLE)
 
+// AP shall drop the sta if contine Tx fail count reach it.
+#define MAC_ENTRY_LIFE_CHECK_CNT		20			// packet cnt.
+
 // Value domain of pMacEntry->Sst
 typedef enum _Sst {
     SST_NOT_AUTH,   // 0: equivalent to IEEE 802.11/1999 state 1
