@@ -81,7 +81,7 @@
 #define MAX_NUMBER_OF_DLS_ENTRY			4
 
 #ifndef UNDER_CE
- 
+
 #define OID_GEN_MACHINE_NAME               0x0001021A
 
 #ifdef RALINK_ATE
@@ -592,7 +592,7 @@ typedef struct _NDIS_802_11_AUTHENTICATION_EVENT
     NDIS_802_11_STATUS_INDICATION       Status;
     NDIS_802_11_AUTHENTICATION_REQUEST  Request[1];
 } NDIS_802_11_AUTHENTICATION_EVENT, *PNDIS_802_11_AUTHENTICATION_EVENT;
-
+        
 // 802.11 Media stream constraints, associated with OID_802_11_MEDIA_STREAM_MODE
 typedef enum _NDIS_802_11_MEDIA_STREAM_MODE
 {
@@ -681,7 +681,7 @@ enum {
 };
 
 #endif // CONFIG_STA_SUPPORT //
- 
+
 #ifdef SNMP_SUPPORT
 //SNMP ieee 802dot11, kathy , 2008_0220
 // dot11res(3)
@@ -711,12 +711,12 @@ enum {
 #define OID_802_11_GET_CH_LIST					0x0715
 #define OID_802_11_GET_COUNTRY_CODE				0x0716
 #define OID_802_11_GET_CHANNEL_GEOGRAPHY		0x0717
- 
+
 #ifdef LLTD_SUPPORT
 // for consistency with RT61
 #define RT_OID_GET_PHY_MODE                         0x761
 #endif // LLTD_SUPPORT //
- 
+
 // New for MeetingHouse Api support
 #define OID_MH_802_1X_SUPPORTED               0xFFEDC100
 
@@ -760,6 +760,7 @@ typedef enum _RT_802_11_PHY_MODE {
 	PHY_11A,
 	PHY_11ABG_MIXED,
 	PHY_11G,
+#ifdef DOT11_N_SUPPORT
 	PHY_11ABGN_MIXED,	// both band   5
 	PHY_11N_2_4G,		// 11n-only with 2.4G band   	6
 	PHY_11GN_MIXED,	// 2.4G band      7
@@ -767,16 +768,9 @@ typedef enum _RT_802_11_PHY_MODE {
 	PHY_11BGN_MIXED,	// if check 802.11b.      9
 	PHY_11AGN_MIXED,	// if check 802.11b.      10
 	PHY_11N_5G,			// 11n-only with 5G band		11
+#endif // DOT11_N_SUPPORT //
 } RT_802_11_PHY_MODE;
 
-typedef enum _RT_802_11_ADHOC_MODE {
-	ADHOC_11B,
-	ADHOC_11BG_MIXED,
-	ADHOC_11G,
-	ADHOC_11A,
-	ADHOC_11ABG_MIXED
-} RT_802_11_ADHOC_MODE;
-
 // put all proprietery for-query objects here to reduce # of Query_OID
 typedef struct _RT_802_11_LINK_STATUS {
     ULONG   CurrTxRate;         // in units of 0.5Mbps
@@ -927,7 +921,7 @@ typedef struct {
 	UCHAR		SHORTGI;
 	UCHAR		rsv;
 } OID_SET_HT_PHYMODE, *POID_SET_HT_PHYMODE;
- 
+
 #ifdef LLTD_SUPPORT
 typedef struct _RT_LLTD_ASSOICATION_ENTRY {
     UCHAR           Addr[ETH_LENGTH_OF_ADDRESS];
@@ -978,7 +972,7 @@ typedef enum _RT_802_11_DLS_MODE {
 #endif // NATIVE_WPA_SUPPLICANT_SUPPORT //
 #endif // WPA_SUPPLICANT_SUPPORT //
 #endif // CONFIG_STA_SUPPORT //
- 
+
 #define MAX_CUSTOM_LEN 128 
 
 #ifdef CONFIG_STA_SUPPORT
@@ -995,6 +989,7 @@ typedef struct _RT_CHANNEL_LIST_INFO
 	UCHAR ChannelList[MAX_NUM_OF_CHS];   // list all supported channels for site survey
 	UCHAR ChannelListNum; // number of channel in ChannelList[]
 } RT_CHANNEL_LIST_INFO, *PRT_CHANNEL_LIST_INFO;
- 
+
+
 #endif // _OID_H_
 
