@@ -210,7 +210,6 @@
 #define fOP_STATUS_TX_AMSDU_INUSED			0x00002000
 #define fOP_STATUS_MAX_RETRY_ENABLED		0x00004000
 #define fOP_STATUS_WAKEUP_NOW               0x00008000
-#define fOP_STATUS_CLKSELECT_40MHZ          0x00010000
 #define fOP_STATUS_ADVANCE_POWER_SAVE_PCIE_DEVICE       0x00020000
 
 #ifdef DOT11N_DRAFT3
@@ -329,7 +328,7 @@
 #ifdef MBSS_SUPPORT
 #undef	MAX_MBSSID_NUM
 #define MAX_MBSSID_NUM				(8 - MAX_MESH_NUM - MAX_APCLI_NUM)
-#endif /* !MBSS_SUPPORT */
+#endif // MBSS_SUPPORT //
 
 /* sanity check for apidx */
 #define MBSS_MR_APIDX_SANITY_CHECK(apidx) \
@@ -1097,8 +1096,10 @@
 // Preamble MODE in TxD
 #define MODE_CCK	0
 #define MODE_OFDM   1
+#ifdef DOT11_N_SUPPORT
 #define MODE_HTMIX	2
 #define MODE_HTGREENFIELD	3
+#endif // DOT11_N_SUPPORT //
 // MCS for CCK.  BW.SGI.STBC are reserved
 #define MCS_LONGP_RATE_1                      0	 // long preamble CCK 1Mbps
 #define MCS_LONGP_RATE_2                      1	// long preamble CCK 1Mbps
@@ -1145,10 +1146,12 @@
 #define MCS_32		32
 #define MCS_AUTO		33
 
+#ifdef DOT11_N_SUPPORT
 // OID_HTPHYMODE
 // MODE
 #define HTMODE_MM	0	 
 #define HTMODE_GF	1
+#endif // DOT11_N_SUPPORT //
 
 // Fixed Tx MODE - HT, CCK or OFDM
 #define FIXED_TXMODE_HT		0
@@ -1159,12 +1162,16 @@
 #define BW_40		BAND_WIDTH_40
 #define BW_BOTH		BAND_WIDTH_BOTH
 #define BW_10		BAND_WIDTH_10	// 802.11j has 10MHz. This definition is for internal usage. doesn't fill in the IE or other field.
+
+#ifdef DOT11_N_SUPPORT
 // SHORTGI
 #define GI_400		GAP_INTERVAL_400	// only support in HT mode
-#define GI_800		GAP_INTERVAL_800	
 #define GI_BOTH		GAP_INTERVAL_BOTH
+#endif // DOT11_N_SUPPORT //
+#define GI_800		GAP_INTERVAL_800	
 // STBC
 #define STBC_NONE	0
+#ifdef DOT11_N_SUPPORT
 #define STBC_USE	1	// limited use in rt2860b phy
 #define RXSTBC_ONE	1	// rx support of one spatial stream
 #define RXSTBC_TWO	2	// rx support of 1 and 2 spatial stream
@@ -1186,6 +1193,8 @@
 #define	AMSDU_0	0
 #define	AMSDU_1		1
 
+#endif // DOT11_N_SUPPORT //
+
 // MCS use 7 bits 
 #define TXRATEMIMO		0x80
 #define TXRATEMCS		0x7F
@@ -1269,12 +1278,15 @@
 #define CIPHER_CKIP64               5
 #define CIPHER_CKIP128              6
 #define CIPHER_TKIP_NO_MIC          7       // MIC appended by driver: not a valid value in hardware key table
+#define CIPHER_SMS4					8
 
 // value domain of pAd->RfIcType
 #define RFIC_2820                   1       // 2.4G 2T3R
 #define RFIC_2850                   2       // 2.4G/5G 2T3R
 #define RFIC_2720                   3       // 2.4G 1T2R
 #define RFIC_2750                   4       // 2.4G/5G 1T2R
+#define RFIC_3020                   5       // 2.4G 1T1R
+#define RFIC_2020                   6       // 2.4G B/G
 
 // LED Status.
 #define LED_LINK_DOWN               0
@@ -1301,23 +1313,6 @@
 #define PAIRWISE_KEY                1
 #define GROUP_KEY                   2
 
-#define PCI_CFG_ADDR_PORT           0xcf8
-#define PCI_CFG_DATA_PORT           0xcfc
-
-// vendor ID
-#define RICOH                       0x1180
-#define O2MICRO                     0x1217
-#define TI                          0x104c
-#define RALINK                      0x1814
-#define TOSHIBA                     0x1179
-#define ENE                         0x1524
-#define UNKNOWN                     0xffff
-
-#define CARD_BRIDGE_CLASS           0x0607          // CardBus bridge class & subclass
-
-#define MAX_PCI_DEVICE              32      // support up to 32 devices per bus
-#define MAX_PCI_BUS                 32      // support 10 buses
-#define MAX_FUNC_NUM                4
 //definition of DRS
 #define MAX_STEP_OF_TX_RATE_SWITCH	32
 
@@ -1489,6 +1484,7 @@
 #define	IW_FLOOD_EVENT_FLAG_END                   	0x0406
 #define	IW_FLOOD_EVENT_TYPE_NUM						(IW_FLOOD_EVENT_FLAG_END - IW_FLOOD_EVENT_FLAG_START + 1)
 // For flooding attack - end 
+
 // End - WIRELESS EVENTS definition
 
 #ifdef CONFIG_STA_SUPPORT
@@ -1515,6 +1511,7 @@
 #define MCAST_DISABLE	0
 #define MCAST_CCK		1
 #define MCAST_OFDM		2
+#define MCAST_HTMIX		3
 #endif // MCAST_RATE_SPECIFIC //
 
 // For AsicRadioOff/AsicRadioOn function
@@ -1524,6 +1521,12 @@
 #define GUI_IDLE_POWER_SAVE		3
 // --
 
+
+// definition for WpaSupport flag
+#define WPA_SUPPLICANT_DISABLE				0
+#define WPA_SUPPLICANT_ENABLE				1
+#define	WPA_SUPPLICANT_ENABLE_WITH_WEB_UI	2
+
 // Endian byte swapping codes
 #define SWAP16(x) \
     ((UINT16)( \
