@@ -294,10 +294,6 @@ VOID	RTMPFreeAdapter(
 	NdisFreeSpinLock(&pAd->MgmtRingLock);
 	
 #ifdef RT2860 
-#ifdef WIN_NDIS
-	NdisFreeSpinLock(&pAd->TxRingLock);	
-	NdisFreeSpinLock(&pAd->LocalTxBufQueueLock);
-#endif
 	NdisFreeSpinLock(&pAd->RxRingLock);
 #endif // RT2860 //
 
@@ -863,7 +859,7 @@ void send_monitor_packets(
     }
         
     pOSPkt = RTPKT_TO_OSPKT(pRxBlk->pRxPacket);
-	pOSPkt->dev = get_netdev_from_bssid(pAd, BSS0);
+	pOSPkt->dev = get_netdev_from_bssid(pAd, BSS0); 
     if (pRxBlk->pHeader->FC.Type == BTYPE_DATA)
     {
         pRxBlk->DataSize -= LENGTH_802_11;
@@ -900,7 +896,7 @@ void send_monitor_packets(
             pRxBlk->pData += header_len;
     } //end if
 
-                
+
 	if (pRxBlk->DataSize < pOSPkt->len) {
         skb_trim(pOSPkt,pRxBlk->DataSize);
     } else {
@@ -965,11 +961,14 @@ void send_monitor_packets(
 	ph->noise.len = 4;
 	ph->noise.data = 0;
 
+#ifdef DOT11_N_SUPPORT
     if (pRxBlk->pRxWI->PHYMODE >= MODE_HTMIX)
     {
     	rate_index = 16 + ((UCHAR)pRxBlk->pRxWI->BW *16) + ((UCHAR)pRxBlk->pRxWI->ShortGI *32) + ((UCHAR)pRxBlk->pRxWI->MCS);
     }
-    else if (pRxBlk->pRxWI->PHYMODE == MODE_OFDM)
+    else
+#endif // DOT11_N_SUPPORT //
+	if (pRxBlk->pRxWI->PHYMODE == MODE_OFDM)
     	rate_index = (UCHAR)(pRxBlk->pRxWI->MCS) + 4;
     else 
     	rate_index = (UCHAR)(pRxBlk->pRxWI->MCS);
