@@ -24,7 +24,6 @@
  *                                                                       * 
  *************************************************************************
 
-
     Module Name:
     rt_main_dev.c
 
@@ -70,8 +69,10 @@ MODULE_PARM_DESC (mac, "rt28xx: wireless mac addr");
 /*---------------------------------------------------------------------*/
 /* Prototypes of Functions Used                                        */
 /*---------------------------------------------------------------------*/
+#ifdef DOT11_N_SUPPORT
 extern BOOLEAN ba_reordering_resource_init(PRTMP_ADAPTER pAd, int num);
 extern void ba_reordering_resource_release(PRTMP_ADAPTER pAd);
+#endif // DOT11_N_SUPPORT //
 extern NDIS_STATUS NICLoadRateSwitchingParams(IN PRTMP_ADAPTER pAd);
 
 #ifdef RT2860
@@ -216,7 +217,7 @@ int rt28xx_close(IN PNET_DEV dev)
 {
 	struct net_device * net_dev = (struct net_device *)dev;
     RTMP_ADAPTER	*pAd = net_dev->priv;
-	BOOLEAN			Cancelled = FALSE;
+	BOOLEAN 		Cancelled = FALSE;
 	UINT32			i = 0;
 
 
@@ -226,14 +227,10 @@ int rt28xx_close(IN PNET_DEV dev)
 	if (pAd == NULL)
 		return 0; // close ok
 
-	// when users do "Suspend to Disk" and reboot the computer, Fedora OS
-	// will call rt28xx_close() when OS does not yet finish rtusb_disconnect()
-	//
-	// rtusb_disconnect() will set fRTMP_ADAPTER_NIC_NOT_EXIST, so we need to
-	// check the bit, we can not do rt28xx_close() in the duration of
-	// rtusb_disconnect()
-	if (RTMP_TEST_FLAG(pAd, fRTMP_ADAPTER_NIC_NOT_EXIST))
-		return 0;
+
+#ifdef WDS_SUPPORT
+	WdsDown(pAd);
+#endif // WDS_SUPPORT //
 
 #ifdef CONFIG_STA_SUPPORT
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
@@ -250,34 +247,34 @@ int rt28xx_close(IN PNET_DEV dev)
         }
 
 #ifdef QOS_DLS_SUPPORT
-	// send DLS-TEAR_DOWN message, 
-	if (pAd->CommonCfg.bDLSCapable)
-	{
-		UCHAR i;
-
-		// tear down local dls table entry
-		for (i=0; i<MAX_NUM_OF_INIT_DLS_ENTRY; i++)
+		// send DLS-TEAR_DOWN message, 
+		if (pAd->CommonCfg.bDLSCapable)
 		{
-			if (pAd->StaCfg.DLSEntry[i].Valid && (pAd->StaCfg.DLSEntry[i].Status == DLS_FINISH))
-			{
-				RTMPSendDLSTearDownFrame(pAd, pAd->StaCfg.DLSEntry[i].MacAddr);
-				pAd->StaCfg.DLSEntry[i].Status	= DLS_NONE;
-				pAd->StaCfg.DLSEntry[i].Valid	= FALSE;
-			}
-		}
+			UCHAR i;
 
-		// tear down peer dls table entry
-		for (i=MAX_NUM_OF_INIT_DLS_ENTRY; i<MAX_NUM_OF_DLS_ENTRY; i++)
-		{
-			if (pAd->StaCfg.DLSEntry[i].Valid && (pAd->StaCfg.DLSEntry[i].Status == DLS_FINISH))
+			// tear down local dls table entry
+			for (i=0; i<MAX_NUM_OF_INIT_DLS_ENTRY; i++)
 			{
-				RTMPSendDLSTearDownFrame(pAd, pAd->StaCfg.DLSEntry[i].MacAddr);
-				pAd->StaCfg.DLSEntry[i].Status = DLS_NONE;
-				pAd->StaCfg.DLSEntry[i].Valid	= FALSE;
+				if (pAd->StaCfg.DLSEntry[i].Valid && (pAd->StaCfg.DLSEntry[i].Status == DLS_FINISH))
+				{
+					RTMPSendDLSTearDownFrame(pAd, pAd->StaCfg.DLSEntry[i].MacAddr);
+					pAd->StaCfg.DLSEntry[i].Status	= DLS_NONE;
+					pAd->StaCfg.DLSEntry[i].Valid	= FALSE;
+				}
 			}
+
+			// tear down peer dls table entry
+			for (i=MAX_NUM_OF_INIT_DLS_ENTRY; i<MAX_NUM_OF_DLS_ENTRY; i++)
+			{
+				if (pAd->StaCfg.DLSEntry[i].Valid && (pAd->StaCfg.DLSEntry[i].Status == DLS_FINISH))
+				{
+					RTMPSendDLSTearDownFrame(pAd, pAd->StaCfg.DLSEntry[i].MacAddr);
+					pAd->StaCfg.DLSEntry[i].Status = DLS_NONE;
+					pAd->StaCfg.DLSEntry[i].Valid	= FALSE;
+				}
+			}
+			RT28XX_MLME_HANDLER(pAd);
 		}
-		RT28XX_MLME_HANDLER(pAd);
-	}
 #endif // QOS_DLS_SUPPORT //
 
 		if (INFRA_ON(pAd) &&
@@ -305,12 +302,14 @@ int rt28xx_close(IN PNET_DEV dev)
 			RTMPusecDelay(1000);
 		}
 
+
 #ifdef CCX_SUPPORT
 		RTMPCancelTimer(&pAd->StaCfg.LeapAuthTimer, &Cancelled);
 #endif
 
 		RTMPCancelTimer(&pAd->StaCfg.StaQuickResponeForRateUpTimer, &Cancelled);
 		RTMPCancelTimer(&pAd->StaCfg.WpaDisassocAndBlockAssocTimer, &Cancelled);
+
 #ifdef WPA_SUPPLICANT_SUPPORT
 #ifndef NATIVE_WPA_SUPPLICANT_SUPPORT
 		{
@@ -351,7 +350,7 @@ int rt28xx_close(IN PNET_DEV dev)
 #ifdef CONFIG_STA_SUPPORT
 	IF_DEV_CONFIG_OPMODE_ON_STA(pAd)
 	{
-		STAMacTableReset(pAd);
+		MacTableReset(pAd);
 	}
 #endif // CONFIG_STA_SUPPORT //
 
@@ -359,6 +358,7 @@ int rt28xx_close(IN PNET_DEV dev)
 	MeasureReqTabExit(pAd);
 	TpcReqTabExit(pAd);
 
+
 #ifdef RT2860
 	if (RTMP_TEST_FLAG(pAd, fRTMP_ADAPTER_INTERRUPT_ACTIVE))
 	{
@@ -383,10 +383,12 @@ int rt28xx_close(IN PNET_DEV dev)
 
 	RTMP_CLEAR_FLAG(pAd, fRTMP_ADAPTER_HALT_IN_PROGRESS);
 
-
+#ifdef DOT11_N_SUPPORT
 	// Free BA reorder resource
 	ba_reordering_resource_release(pAd);
+#endif // DOT11_N_SUPPORT //
 	
+
 	RTMP_CLEAR_FLAG(pAd, fRTMP_ADAPTER_START_UP);
 
 	return 0; // close ok
@@ -400,9 +402,11 @@ static int rt28xx_init(IN struct net_device *net_dev)
 	NDIS_STATUS				Status;
 	UINT32 		MacCsr0 = 0;
 
+
+#ifdef DOT11_N_SUPPORT
 	// Allocate BA Reordering memory
 	ba_reordering_resource_init(pAd, MAX_REORDERING_MPDU_NUM);
-	
+#endif // DOT11_N_SUPPORT //
 
 	// Make sure MAC gets ready.
 	index = 0;
@@ -509,6 +513,7 @@ static int rt28xx_init(IN struct net_device *net_dev)
 
 
    	//Init Ba Capability parameters.
+#ifdef DOT11_N_SUPPORT
 	pAd->CommonCfg.DesiredHtPhy.MpduDensity = (UCHAR)pAd->CommonCfg.BACapability.field.MpduDensity;
 	pAd->CommonCfg.DesiredHtPhy.AmsduEnable = (USHORT)pAd->CommonCfg.BACapability.field.AmsduEnable;
 	pAd->CommonCfg.DesiredHtPhy.AmsduSize = (USHORT)pAd->CommonCfg.BACapability.field.AmsduSize;
@@ -517,6 +522,7 @@ static int rt28xx_init(IN struct net_device *net_dev)
 	pAd->CommonCfg.HtCapability.HtCapInfo.MimoPs = (USHORT)pAd->CommonCfg.BACapability.field.MMPSmode;
 	pAd->CommonCfg.HtCapability.HtCapInfo.AMsduSize = (USHORT)pAd->CommonCfg.BACapability.field.AmsduSize;
 	pAd->CommonCfg.HtCapability.HtCapParm.MpduDensity = (UCHAR)pAd->CommonCfg.BACapability.field.MpduDensity;
+#endif // DOT11_N_SUPPORT //
 
 	printk("2. Phy Mode = %d\n", pAd->CommonCfg.PhyMode);
 
@@ -525,11 +531,15 @@ static int rt28xx_init(IN struct net_device *net_dev)
 
 	printk("3. Phy Mode = %d\n", pAd->CommonCfg.PhyMode);
 
+	NICInitAsicFromEEPROM(pAd); //rt2860b
+
 	// Set PHY to appropriate mode
 	TmpPhy = pAd->CommonCfg.PhyMode;
 	pAd->CommonCfg.PhyMode = 0xff;
 	RTMPSetPhyMode(pAd, TmpPhy);
+#ifdef DOT11_N_SUPPORT
 	SetCommonHT(pAd);
+#endif // DOT11_N_SUPPORT //
 
 	// No valid channels.
 	if (pAd->ChannelListNum == 0)
@@ -537,11 +547,12 @@ static int rt28xx_init(IN struct net_device *net_dev)
 		printk("Wrong configuration. No valid channel found. Check \"ContryCode\" and \"ChannelGeography\" setting.\n");
 		goto err4;
 	}
-	
+
+#ifdef DOT11_N_SUPPORT
 	printk("MCS Set = %02x %02x %02x %02x %02x\n", pAd->CommonCfg.HtCapability.MCSSet[0],
            pAd->CommonCfg.HtCapability.MCSSet[1], pAd->CommonCfg.HtCapability.MCSSet[2],
            pAd->CommonCfg.HtCapability.MCSSet[3], pAd->CommonCfg.HtCapability.MCSSet[4]);
-	NICInitAsicFromEEPROM(pAd); //rt2860b
+#endif // DOT11_N_SUPPORT //
 
 #ifdef IKANOS_VX_1X0
 	VR_IKANOS_FP_Init(pAd->ApCfg.BssidNum, pAd->PermanentAddress);
@@ -558,10 +569,11 @@ static int rt28xx_init(IN struct net_device *net_dev)
 
 	if (pAd && (Status != NDIS_STATUS_SUCCESS))
 	{
-
+		//
+		// Undo everything if it failed
+		//
 		if (RTMP_TEST_FLAG(pAd, fRTMP_ADAPTER_INTERRUPT_IN_USE))
 		{
-
 			RTMP_CLEAR_FLAG(pAd, fRTMP_ADAPTER_INTERRUPT_IN_USE);
 		}
 	}
@@ -571,8 +583,11 @@ static int rt28xx_init(IN struct net_device *net_dev)
 		OPSTATUS_CLEAR_FLAG(pAd, fOP_STATUS_MEDIA_STATE_CONNECTED);
 		RTMP_SET_FLAG(pAd, fRTMP_ADAPTER_MEDIA_STATE_CHANGE);
 		DBGPRINT(RT_DEBUG_TRACE, ("NDIS_STATUS_MEDIA_DISCONNECT Event B!\n"));
+
+
 	}// end of else
 
+
 	DBGPRINT_S(Status, ("<==== RTMPInitialize, Status=%x\n", Status));
 
 	return TRUE;
@@ -585,9 +600,16 @@ err2:
 	RTMPFreeTxRxRingMemory(pAd);
 err1:
 
+#ifdef DOT11_N_SUPPORT
 	os_free_mem(pAd, pAd->mpdu_blk_pool.mem); // free BA pool
+#endif // DOT11_N_SUPPORT //
 	RT28XX_IRQ_RELEASE(net_dev);
-	
+
+	// shall not set priv to NULL here because the priv didn't been free yet.
+	//net_dev->priv = 0;
+#ifdef INF_AMAZON_SE
+err0:
+#endif // INF_AMAZON_SE //
 	printk("!!! %s Initialized fail !!!\n", RT28xx_CHIP_NAME);
 	return FALSE;
 } /* End of rt28xx_init */
@@ -801,7 +823,11 @@ static NDIS_STATUS rt_ieee80211_if_setup(struct net_device *dev, PRTMP_ADAPTER p
 	    
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,0)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,26)
+        device = dev_get_by_name(dev_net(dev), slot_name);
+#else
         device = dev_get_by_name(dev->nd_net, slot_name);
+#endif
 #else
 		device = dev_get_by_name(slot_name);
 #endif
@@ -830,7 +856,6 @@ static NDIS_STATUS rt_ieee80211_if_setup(struct net_device *dev, PRTMP_ADAPTER p
 		else
 #endif // MULTIPLE_CARD_SUPPORT //
 		sprintf(dev->name, "ra%d", i);
-		DBGPRINT(RT_DEBUG_INFO, ("Assign the net device name as %s\n", dev->name));
 		Status = NDIS_STATUS_SUCCESS;
 	}
 
@@ -918,7 +943,7 @@ BOOLEAN RTMP_CardInfoRead(
 	else
 		pAd->EEPROMAddressNum = 8;	// 93C86
 
-	antenna.word = RTMP_EEPROM_READ16(pAd, EEPROM_NIC1_OFFSET);
+	RT28xx_EEPROM_READ16(pAd, EEPROM_NIC1_OFFSET, antenna.word);
 
 	if ((antenna.field.RfIcType == RFIC_2850) ||
 		(antenna.field.RfIcType == RFIC_2750))
@@ -933,9 +958,9 @@ BOOLEAN RTMP_CardInfoRead(
 	}
 
 	// get MAC address
-	addr01 = RTMP_EEPROM_READ16(pAd, 0x04);
-	addr23 = RTMP_EEPROM_READ16(pAd, 0x06);
-	addr45 = RTMP_EEPROM_READ16(pAd, 0x08);
+	RT28xx_EEPROM_READ16(pAd, 0x04, addr01);
+	RT28xx_EEPROM_READ16(pAd, 0x06, addr23);
+	RT28xx_EEPROM_READ16(pAd, 0x08, addr45);
 
 	mac[0] = (UCHAR)(addr01 & 0xff);
 	mac[1] = (UCHAR)(addr01 >> 8);
@@ -1407,7 +1432,7 @@ int rt28xx_packet_xmit(struct sk_buff *skb)
 		RELEASE_NDIS_PACKET(pAd, pPacket, NDIS_STATUS_FAILURE);
 		goto done;
 	}
-
+	
 	RTMP_SET_PACKET_5VT(pPacket, 0);
 #ifdef CONFIG_5VT_ENHANCE
     if (*(int*)(skb->cb) == BRIDGE_TAG) {
@@ -1463,7 +1488,7 @@ INT rt28xx_send_packets(
 	NdisZeroMemory((PUCHAR)&skb_p->cb[CB_OFF], 15);
 	RTMP_SET_PACKET_NET_DEVICE_MBSSID(skb_p, MAIN_MBSSID);
 
-		return rt28xx_packet_xmit(skb_p);
+	return rt28xx_packet_xmit(skb_p);
 
 } /* End of MBSS_VirtualIF_PacketSend */
 
@@ -1619,8 +1644,7 @@ struct net_device_stats *RT28xx_get_ether_stats(
 
 	if (pAd)
 	{
-	    DBGPRINT(RT_DEBUG_INFO, ("RT28xx_get_ether_stats --->\n"));
-
+	   
 		pAd->stats.rx_packets = pAd->WlanCounters.ReceivedFragmentCount.QuadPart;
 		pAd->stats.tx_packets = pAd->WlanCounters.TransmittedFragmentCount.QuadPart;
 
