@@ -142,7 +142,6 @@ VOID AssocTimeout(IN PVOID SystemSpecific1,
 				 IN PVOID SystemSpecific3) 
 {
 	RTMP_ADAPTER *pAd = (RTMP_ADAPTER *)FunctionContext;
-	DBGPRINT(RT_DEBUG_INFO,("ASSOC - enqueue MT2_ASSOC_TIMEOUT \n"));
 	
 	// Do nothing if the driver is starting halt state.
 	// This might happen when timer already been fired before cancel timer with mlmehalt
@@ -171,7 +170,6 @@ VOID ReassocTimeout(IN PVOID SystemSpecific1,
 					IN PVOID SystemSpecific3) 
 {
 	RTMP_ADAPTER *pAd = (RTMP_ADAPTER *)FunctionContext;
-	DBGPRINT(RT_DEBUG_INFO,("ASSOC - enqueue MT2_REASSOC_TIMEOUT \n"));
 	
 	// Do nothing if the driver is starting halt state.
 	// This might happen when timer already been fired before cancel timer with mlmehalt
@@ -200,7 +198,6 @@ VOID DisassocTimeout(IN PVOID SystemSpecific1,
 					IN PVOID SystemSpecific3) 
 {
 	RTMP_ADAPTER *pAd = (RTMP_ADAPTER *)FunctionContext;
-	DBGPRINT(RT_DEBUG_INFO,("ASSOC - enqueue MT2_DISASSOC_TIMEOUT \n"));
 	
 	// Do nothing if the driver is starting halt state.
 	// This might happen when timer already been fired before cancel timer with mlmehalt
@@ -344,6 +341,7 @@ VOID MlmeAssocReqAction(
 			FrameLen += tmp;
 		}
 
+#ifdef DOT11_N_SUPPORT
 		// HT
 		if ((pAd->MlmeAux.HtCapabilityLen > 0) && (pAd->CommonCfg.PhyMode >= PHY_11ABGN_MIXED))
 		{
@@ -387,6 +385,7 @@ VOID MlmeAssocReqAction(
 			}
 			FrameLen += TmpLen;
 		}
+#endif // DOT11_N_SUPPORT //
 
 		// add Ralink proprietary IE to inform AP this STA is going to use AGGREGATION or PIGGY-BACK+AGGREGATION
 		// Case I: (Aggregation + Piggy-Back)
@@ -459,16 +458,20 @@ VOID MlmeAssocReqAction(
 		// For example: Put Vendor Specific IE on the front of WPA IE.
 		// This happens on AP (Model No:Linksys WRK54G)
 		//		
-		if ((pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPAPSK) || 
+		if (((pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPAPSK) || 
             (pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA2PSK) ||
             (pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA) || 
-            (pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA2))
+            (pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA2)
+			)            
+            )          
 		{
 			UCHAR RSNIe = IE_WPA;
 			
 			if ((pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA2PSK) ||
                 (pAd->StaCfg.AuthMode == Ndis802_11AuthModeWPA2))
+			{
 				RSNIe = IE_WPA2;
+			}	
 			
 #ifdef NATIVE_WPA_SUPPLICANT_SUPPORT
 #ifdef SIOCSIWGENIE
@@ -616,6 +619,7 @@ VOID MlmeAssocReqAction(
 			// End Add by James 
 		}		
 
+
 		MiniportMMRequest(pAd, 0, pOutBuffer, FrameLen);
 		MlmeFreeMemory(pAd, pOutBuffer);
 
@@ -755,6 +759,7 @@ VOID MlmeReassocReqAction(
 			FrameLen += tmp;
 		}
 
+#ifdef DOT11_N_SUPPORT
 		// HT
 		if ((pAd->MlmeAux.HtCapabilityLen > 0) && (pAd->CommonCfg.PhyMode >= PHY_11ABGN_MIXED))
 		{
@@ -781,6 +786,8 @@ VOID MlmeReassocReqAction(
 			}
 			FrameLen += TmpLen;
 		}
+#endif // DOT11_N_SUPPORT //
+
 		// add Ralink proprietary IE to inform AP this STA is going to use AGGREGATION or PIGGY-BACK+AGGREGATION
 		// Case I: (Aggregation + Piggy-Back)
 		// 1. user enable aggregation, AND
@@ -984,6 +991,8 @@ VOID MlmeDisassocReqAction(
 		return;
 	}
 
+
+
 	RTMPCancelTimer(&pAd->MlmeAux.DisassocTimer, &TimerCancelled);
 
 	DBGPRINT(RT_DEBUG_TRACE, ("ASSOC - Send DISASSOC request[BSSID::%02x:%02x:%02x:%02x:%02x:%02x (Reason=%d)\n", 
@@ -1013,7 +1022,8 @@ VOID MlmeDisassocReqAction(
 
 #ifdef WPA_SUPPLICANT_SUPPORT
 #ifndef NATIVE_WPA_SUPPLICANT_SUPPORT
-    if (pAd->StaCfg.WpaSupplicantUP) {
+    if (pAd->StaCfg.WpaSupplicantUP != WPA_SUPPLICANT_DISABLE) 
+	{
         union iwreq_data    wrqu;
         //send disassociate event to wpa_supplicant
         memset(&wrqu, 0, sizeof(wrqu));
@@ -1068,7 +1078,9 @@ VOID PeerAssocRspAction(
 		if(MAC_ADDR_EQUAL(Addr2, pAd->MlmeAux.Bssid)) 
 		{
 			DBGPRINT(RT_DEBUG_TRACE, ("PeerAssocRspAction():ASSOC - receive ASSOC_RSP to me (status=%d)\n", Status));
+#ifdef DOT11_N_SUPPORT
 			DBGPRINT(RT_DEBUG_TRACE, ("PeerAssocRspAction():MacTable [%d].AMsduSize = %d. ClientStatusFlags = 0x%lx \n",Elem->Wcid, pAd->MacTab.Content[BSSID_WCID].AMsduSize, pAd->MacTab.Content[BSSID_WCID].ClientStatusFlags));
+#endif // DOT11_N_SUPPORT //
 			RTMPCancelTimer(&pAd->MlmeAux.AssocTimer, &TimerCancelled);
 			if(Status == MLME_SUCCESS) 
 			{
@@ -1078,7 +1090,7 @@ VOID PeerAssocRspAction(
 
 #ifdef WPA_SUPPLICANT_SUPPORT
 #ifndef NATIVE_WPA_SUPPLICANT_SUPPORT
-                if (pAd->StaCfg.WpaSupplicantUP)
+                if (pAd->StaCfg.WpaSupplicantUP != WPA_SUPPLICANT_DISABLE)
                 {
                     union iwreq_data    wrqu;
 
@@ -1183,7 +1195,7 @@ VOID PeerReassocRspAction(
 
 #ifdef WPA_SUPPLICANT_SUPPORT
 #ifndef NATIVE_WPA_SUPPLICANT_SUPPORT
-                if (pAd->StaCfg.WpaSupplicantUP)
+                if (pAd->StaCfg.WpaSupplicantUP != WPA_SUPPLICANT_DISABLE)
                 {
                     union iwreq_data    wrqu;
 
@@ -1284,6 +1296,7 @@ VOID AssocPostProc(
 	COPY_MAC_ADDR(pAd->MlmeAux.Bssid, pAddr2);
 	pAd->MlmeAux.Aid = Aid;
 	pAd->MlmeAux.CapabilityInfo = CapabilityInfo & SUPPORTED_CAPABILITY_INFO;
+#ifdef DOT11_N_SUPPORT
 	// Some HT AP might lost WMM IE. We add WMM ourselves. beacuase HT requires QoS on.
 	if ((HtCapabilityLen > 0) && (pEdcaParm->bValid == FALSE))
 	{
@@ -1309,6 +1322,7 @@ VOID AssocPostProc(
 		pEdcaParm->Txop[3]  = 48;
 
 	}
+#endif // DOT11_N_SUPPORT //
 
 	NdisMoveMemory(&pAd->MlmeAux.APEdcaParm, pEdcaParm, sizeof(EDCA_PARM));
 
@@ -1322,6 +1336,7 @@ VOID AssocPostProc(
 	NdisMoveMemory(pAd->MlmeAux.ExtRate, ExtRate, ExtRateLen);
 	RTMPCheckRates(pAd, pAd->MlmeAux.ExtRate, &pAd->MlmeAux.ExtRateLen);
 
+#ifdef DOT11_N_SUPPORT
 	if (HtCapabilityLen > 0)
 	{
 		RTMPCheckHt(pAd, BSSID_WCID, pHtCapability, pAddHtInfo);
@@ -1330,6 +1345,8 @@ VOID AssocPostProc(
 		
 	DBGPRINT(RT_DEBUG_TRACE, ("AssocPostProc===>    (Mmps=%d, AmsduSize=%d, )\n", 
 		pAd->MacTab.Content[BSSID_WCID].MmpsMode, pAd->MacTab.Content[BSSID_WCID].AMsduSize));
+#endif // DOT11_N_SUPPORT //
+
 	// Set New WPA information
 	Idx = BssTableSearch(&pAd->ScanTab, pAddr2, pAd->MlmeAux.Channel);
 	if (Idx == BSS_NOT_FOUND) 
@@ -1418,6 +1435,7 @@ VOID PeerDisassocAction(
 				RTMPSendWirelessEvent(pAd, IW_DISASSOC_EVENT_FLAG, pAd->MacTab.Content[BSSID_WCID].Addr, BSS0, 0); 
 			}
 
+
 #ifdef LEAP_SUPPORT
 			if (pAd->StaCfg.LeapAuthMode == CISCO_AuthModeLEAP)
 			{
@@ -1442,7 +1460,8 @@ VOID PeerDisassocAction(
 
 #ifdef WPA_SUPPLICANT_SUPPORT
 #ifndef NATIVE_WPA_SUPPLICANT_SUPPORT
-            if (pAd->StaCfg.WpaSupplicantUP) {
+            if (pAd->StaCfg.WpaSupplicantUP != WPA_SUPPLICANT_DISABLE) 
+			{
                 union iwreq_data    wrqu;
                 //send disassociate event to wpa_supplicant
                 memset(&wrqu, 0, sizeof(wrqu));
