@@ -144,6 +144,7 @@ VOID MlmeDlsReqAction(
 		FrameLen += tmp;
 	}
 
+#ifdef DOT11_N_SUPPORT
 	if ((pAd->CommonCfg.PhyMode >= PHY_11ABGN_MIXED))
 	{
 		UCHAR HtLen;
@@ -173,6 +174,7 @@ VOID MlmeDlsReqAction(
 #endif
 		FrameLen = FrameLen + tmp;
 	}
+#endif // DOT11_N_SUPPORT //
 
 	RTMPCancelTimer(&pDLS->Timer, &TimerCancelled);
 	Timeout = DLS_TIMEOUT;
@@ -347,6 +349,8 @@ VOID PeerDlsReqAction(
 
 					pEntry->MaxHTPhyMode.field.BW = BW_20;
 					pEntry->MinHTPhyMode.field.BW = BW_20;
+
+#ifdef DOT11_N_SUPPORT				
 					pEntry->HTCapability.MCSSet[0] = 0;
 					pEntry->HTCapability.MCSSet[1] = 0;
 
@@ -356,6 +360,9 @@ VOID PeerDlsReqAction(
 						UCHAR	j, bitmask; //k,bitmask;
 						CHAR    ii;
 
+						DBGPRINT(RT_DEBUG_OFF, ("DLS - PeerDlsReqAction() Receive Peer HT Capable STA from %02x:%02x:%02x:%02x:%02x:%02x\n",
+									SA[0], SA[1], SA[2], SA[3], SA[4], SA[5]));
+
 						if ((HtCapability.HtCapInfo.GF) && (pAd->CommonCfg.DesiredHtPhy.GF))
 						{
 							pEntry->MaxHTPhyMode.field.MODE = MODE_HTGREENFIELD;
@@ -439,6 +446,7 @@ VOID PeerDlsReqAction(
 
 						NdisMoveMemory(&pEntry->HTCapability, &HtCapability, sizeof(HT_CAPABILITY_IE));
 					}
+#endif // DOT11_N_SUPPORT //
 
 					pEntry->HTPhyMode.word = pEntry->MaxHTPhyMode.word;
 					pEntry->CurrTxRate = pEntry->MaxSupportedRate;
@@ -509,6 +517,7 @@ VOID PeerDlsReqAction(
 			FrameLen += tmp;
 		}
 
+#ifdef DOT11_N_SUPPORT
 		if ((pAd->CommonCfg.PhyMode >= PHY_11ABGN_MIXED))
 		{
 			UCHAR HtLen;
@@ -538,6 +547,7 @@ VOID PeerDlsReqAction(
 #endif
 			FrameLen = FrameLen + tmp;
 		}
+#endif // DOT11_N_SUPPORT //
 
 		if (pDLS && (pDLS->Status != DLS_FINISH))
 		{
@@ -656,6 +666,8 @@ VOID PeerDlsRspAction(
 
 				pEntry->MaxHTPhyMode.field.BW = BW_20;
 				pEntry->MinHTPhyMode.field.BW = BW_20;
+				
+#ifdef DOT11_N_SUPPORT
 				pEntry->HTCapability.MCSSet[0] = 0;
 				pEntry->HTCapability.MCSSet[1] = 0;
 
@@ -665,6 +677,9 @@ VOID PeerDlsRspAction(
 					UCHAR	j, bitmask; //k,bitmask;
 					CHAR    ii;
 
+					DBGPRINT(RT_DEBUG_OFF, ("DLS - PeerDlsRspAction Receive Peer HT Capable STA from %02x:%02x:%02x:%02x:%02x:%02x\n",
+								SA[0], SA[1], SA[2], SA[3], SA[4], SA[5]));
+
 					if ((HtCapability.HtCapInfo.GF) && (pAd->CommonCfg.DesiredHtPhy.GF))
 					{
 						pEntry->MaxHTPhyMode.field.MODE = MODE_HTGREENFIELD;
@@ -704,8 +719,6 @@ VOID PeerDlsRspAction(
 	 
 					if (pAd->StaCfg.DesiredTransmitSetting.field.MCS != MCS_AUTO)
 					{
-						printk("@@@ pAd->CommonCfg.RegTransmitSetting.field.MCS = %d\n",
-							pAd->StaCfg.DesiredTransmitSetting.field.MCS);
 						if (pAd->StaCfg.DesiredTransmitSetting.field.MCS == 32)
 						{
 							// Fix MCS as HT Duplicated Mode
@@ -746,7 +759,7 @@ VOID PeerDlsRspAction(
 
 					NdisMoveMemory(&pEntry->HTCapability, &HtCapability, sizeof(HT_CAPABILITY_IE));
 				}
-
+#endif // DOT11_N_SUPPORT //
 				pEntry->HTPhyMode.word = pEntry->MaxHTPhyMode.word;
 				pEntry->CurrTxRate = pEntry->MaxSupportedRate;
 				CLIENT_STATUS_SET_FLAG(pEntry, fCLIENT_STATUS_WMM_CAPABLE);
@@ -869,6 +882,8 @@ VOID PeerDlsRspAction(
 
 					pEntry->MaxHTPhyMode.field.BW = BW_20;
 					pEntry->MinHTPhyMode.field.BW = BW_20;
+					
+#ifdef DOT11_N_SUPPORT
 					pEntry->HTCapability.MCSSet[0] = 0;
 					pEntry->HTCapability.MCSSet[1] = 0;
 
@@ -878,6 +893,9 @@ VOID PeerDlsRspAction(
 						UCHAR	j, bitmask; //k,bitmask;
 						CHAR    ii;
 
+						DBGPRINT(RT_DEBUG_OFF, ("DLS - PeerDlsRspAction Receive Peer HT Capable STA from %02x:%02x:%02x:%02x:%02x:%02x\n",
+									SA[0], SA[1], SA[2], SA[3], SA[4], SA[5]));
+
 						if ((HtCapability.HtCapInfo.GF) && (pAd->CommonCfg.DesiredHtPhy.GF))
 						{
 							pEntry->MaxHTPhyMode.field.MODE = MODE_HTGREENFIELD;
@@ -959,6 +977,7 @@ VOID PeerDlsRspAction(
 
 						NdisMoveMemory(&pEntry->HTCapability, &HtCapability, sizeof(HT_CAPABILITY_IE));
 					}
+#endif // DOT11_N_SUPPORT //
 
 					pEntry->HTPhyMode.word = pEntry->MaxHTPhyMode.word;
 					pEntry->CurrTxRate = pEntry->MaxSupportedRate;
@@ -1248,8 +1267,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 	BOOLEAN			TimerCancelled;
 	CIPHER_KEY		PairwiseKey;
 
-	DBGPRINT(RT_DEBUG_INFO, ("====> RTMPRcvFrameDLSCheck\n"));
-
+	
 	if (! pAd->CommonCfg.bDLSCapable)
 		return bSTAKeyFrame;
 
@@ -1334,7 +1352,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 			}
 			else
 				DBGPRINT(RT_DEBUG_TRACE, ("MIC VALID in Msg1 of STAKey handshake! \n"));
-
+#if 1
 			if ((pEap->KeyDesc.KeyData[0] == 0xDD) && (pEap->KeyDesc.KeyData[2] == 0x00) && (pEap->KeyDesc.KeyData[3] == 0x0C)
 				&& (pEap->KeyDesc.KeyData[4] == 0x43) && (pEap->KeyDesc.KeyData[5] == 0x02))
 			{
@@ -1346,10 +1364,27 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 
 				bSTAKeyFrame = TRUE;
 			}
+#else
+			if ((pEap->KeyDesc.KeyData[0] == 0xDD) && (pEap->KeyDesc.KeyData[2] == 0x00) && (pEap->KeyDesc.KeyData[3] == 0x0F)
+				&& (pEap->KeyDesc.KeyData[4] == 0xAC) && (pEap->KeyDesc.KeyData[5] == 0x02))
+			{
+				pAddr			= pEap->KeyDesc.KeyData + 8;		// Tpe(1), Len(1), OUI(3), DataType(1), Reserved(2)
+				pSTAKey			= pEap->KeyDesc.KeyData + 14;	// Tpe(1), Len(1), OUI(3), DataType(1), Reserved(2), STAKey_Mac_Addr(6)
+
+				DBGPRINT(RT_DEBUG_TRACE,("DLS - Receive STAKey Message-1 from %02x:%02x:%02x:%02x:%02x:%02x Len=%d, KeyDataLen=%d\n",
+					pAddr[0], pAddr[1], pAddr[2], pAddr[3], pAddr[4], pAddr[5], Len, pEap->KeyDesc.KeyData[1]));
+
+				bSTAKeyFrame = TRUE;
+			}
+#endif
 			
 		}
 		else if (Len >= (LENGTH_802_11 + 6 + 2 + 2 + sizeof(EAPOL_PACKET) - MAX_LEN_OF_RSNIE))
 		{
+#if 0
+			RTMPMoveMemory(pAd->StaCfg.ReplayCounter, pEap->KeyDesc.ReplayCounter, LEN_KEY_DESC_REPLAY);
+
+#endif
 			RTMPMoveMemory(pAd->StaCfg.DlsReplayCounter, pEap->KeyDesc.ReplayCounter, LEN_KEY_DESC_REPLAY);
 			DBGPRINT(RT_DEBUG_TRACE,("DLS - Sniff replay counter 2(%02x-%02x-%02x-%02x-%02x-%02x-%02x-%02x) Len=%ld, KeyDataLen=%d\n",
 				pAd->StaCfg.ReplayCounter[0], pAd->StaCfg.ReplayCounter[1], pAd->StaCfg.ReplayCounter[2],
@@ -1384,6 +1419,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 				//AsicAddKeyEntry(pAd, (USHORT)(i + 2), BSS0, 0, &PairwiseKey, TRUE, TRUE);	// reserve 0 for multicast, 1 for unicast
 				//AsicUpdateRxWCIDTable(pAd, (USHORT)(i + 2), pAddr);
 				// Add Pair-wise key to Asic
+#ifdef RT2860
             	AsicAddPairwiseKeyEntry(pAd,
 										pAd->StaCfg.DLSEntry[i].MacAddr, 
 										(UCHAR)pAd->StaCfg.DLSEntry[i].MacTabMatchWCID,
@@ -1395,6 +1431,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 										  PairwiseKey.CipherAlg, 
 										  pEntry);
 
+#endif // RT2860 //
 				NdisMoveMemory(&pEntry->PairwiseKey, &PairwiseKey, sizeof(CIPHER_KEY));
 				DBGPRINT(RT_DEBUG_TRACE,("DLS - Receive STAKey Message-1 (Peer STA MAC Address STAKey) \n"));
 
@@ -1440,6 +1477,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 				//AsicAddKeyEntry(pAd, (USHORT)(i + 2), BSS0, 0, &PairwiseKey, TRUE, TRUE);	// reserve 0 for multicast, 1 for unicast
 				//AsicUpdateRxWCIDTable(pAd, (USHORT)(i + 2), pAddr);
 				// Add Pair-wise key to Asic
+#ifdef RT2860
             	AsicAddPairwiseKeyEntry(pAd,
 										pAd->StaCfg.DLSEntry[i].MacAddr, 
 										(UCHAR)pAd->StaCfg.DLSEntry[i].MacTabMatchWCID,
@@ -1450,7 +1488,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 										  0, 
 										  PairwiseKey.CipherAlg, 
 										  pEntry);
-
+#endif // RT2860 //
 				NdisMoveMemory(&pEntry->PairwiseKey, &PairwiseKey, sizeof(CIPHER_KEY));
 				DBGPRINT(RT_DEBUG_TRACE,("DLS - Receive STAKey Message-1 (Initiator STA MAC Address STAKey)\n"));
 
@@ -1483,8 +1521,7 @@ BOOLEAN RTMPRcvFrameDLSCheck(
 			bFindEntry = TRUE;
 		}
 	}
-
-	DBGPRINT(RT_DEBUG_INFO, ("<==== RTMPRcvFrameDLSCheck\n"));
+	
 
 	return bSTAKeyFrame;
 }
@@ -1905,6 +1942,7 @@ MAC_TABLE_ENTRY *MacTableInsertDlsEntry(
 			pEntry->MatchDlsEntryIdx = DlsEntryIdx;
 			pEntry->AuthMode = pAd->StaCfg.AuthMode;
 			pEntry->WepStatus = pAd->StaCfg.WepStatus;
+			pEntry->PortSecured = WPA_802_1X_PORT_SECURED;
 
 			DBGPRINT(RT_DEBUG_TRACE, ("MacTableInsertDlsEntry - allocate entry #%d, Total= %d\n",pEntry->Aid, pAd->MacTab.Size));
 
@@ -2040,10 +2078,36 @@ INT Set_DlsEntryInfo_Display_Proc(
 	{
 		if ((pAd->StaCfg.DLSEntry[i].Valid) && (pAd->StaCfg.DLSEntry[i].Status == DLS_FINISH))
 		{
+			PMAC_TABLE_ENTRY pEntry = &pAd->MacTab.Content[pAd->StaCfg.DLSEntry[i].MacTabMatchWCID];
+
 			printk("%02x:%02x:%02x:%02x:%02x:%02x  ",
 				pAd->StaCfg.DLSEntry[i].MacAddr[0], pAd->StaCfg.DLSEntry[i].MacAddr[1], pAd->StaCfg.DLSEntry[i].MacAddr[2],
 				pAd->StaCfg.DLSEntry[i].MacAddr[3], pAd->StaCfg.DLSEntry[i].MacAddr[4], pAd->StaCfg.DLSEntry[i].MacAddr[5]);
 			printk("%-8d\n", pAd->StaCfg.DLSEntry[i].TimeOut);
+
+			printk("\n");
+			printk("\n%-19s%-4s%-4s%-4s%-4s%-8s%-7s%-7s%-7s%-10s%-6s%-6s%-6s%-6s\n",
+				   "MAC", "AID", "BSS", "PSM", "WMM", "MIMOPS", "RSSI0", "RSSI1", "RSSI2", "PhMd", "BW", "MCS", "SGI", "STBC");
+			printk("%02X:%02X:%02X:%02X:%02X:%02X  ",
+				pEntry->Addr[0], pEntry->Addr[1], pEntry->Addr[2],
+				pEntry->Addr[3], pEntry->Addr[4], pEntry->Addr[5]);
+			printk("%-4d", (int)pEntry->Aid);
+			printk("%-4d", (int)pEntry->apidx);
+			printk("%-4d", (int)pEntry->PsMode);
+			printk("%-4d", (int)CLIENT_STATUS_TEST_FLAG(pEntry, fCLIENT_STATUS_WMM_CAPABLE));
+			printk("%-8d", (int)pEntry->MmpsMode);
+			printk("%-7d", pEntry->RssiSample.AvgRssi0);
+			printk("%-7d", pEntry->RssiSample.AvgRssi1);
+			printk("%-7d", pEntry->RssiSample.AvgRssi2);
+			printk("%-10s", GetPhyMode(pEntry->HTPhyMode.field.MODE));
+			printk("%-6s", GetBW(pEntry->HTPhyMode.field.BW));
+			printk("%-6d", pEntry->HTPhyMode.field.MCS);
+			printk("%-6d", pEntry->HTPhyMode.field.ShortGI);
+			printk("%-6d", pEntry->HTPhyMode.field.STBC);
+			printk("%-10d, %d, %d%%\n", pEntry->DebugFIFOCount, pEntry->DebugTxCount, 
+						(pEntry->DebugTxCount) ? ((pEntry->DebugTxCount-pEntry->DebugFIFOCount)*100/pEntry->DebugTxCount) : 0);
+			printk("\n");
+
 		}
 	}
 
