@@ -90,7 +90,7 @@ VOID STARxEAPOLFrameIndicate(
                         pAd->IndicateMediaState = NdisMediaStateConnected;
                         pAd->ExtraInfo = GENERAL_LINK_UP;
 #endif // RT2860 //
-    					// For Preventing ShardKey Table is cleared by remove key procedure.
+						// For Preventing ShardKey Table is cleared by remove key procedure.
     					pAd->SharedKey[BSS0][idx].CipherAlg = CipherAlg;
 						pAd->SharedKey[BSS0][idx].KeyLen = pAd->StaCfg.DesireSharedKey[idx].KeyLen;
 						NdisMoveMemory(pAd->SharedKey[BSS0][idx].Key, 
@@ -177,11 +177,13 @@ VOID STARxDataFrameAnnounce(
 	else 
 	{
 		RX_BLK_SET_FLAG(pRxBlk, fRX_EAP);
+#ifdef DOT11_N_SUPPORT
 		if (RX_BLK_TEST_FLAG(pRxBlk, fRX_AMPDU) && (pAd->CommonCfg.bDisableReordering == 0)) 
 		{
 			Indicate_AMPDU_Packet(pAd, pRxBlk, FromWhichBSSID);
 		} 
 		else
+#endif // DOT11_N_SUPPORT //
 		{
 			// Determin the destination of the EAP frame
 			//  to WPA state machine or upper layer
@@ -409,7 +411,6 @@ VOID STAHandleRxDataFrame(
 			{
 				AsicUpdateProtect(pAd, 8, ALLN_SETPROTECT, TRUE, FALSE);
 			}
-			DBGPRINT(RT_DEBUG_INFO, ("Atheros Problem. Turn on RTS/CTS!!!\n"));
 		}
 	}
 
@@ -447,17 +448,19 @@ VOID STAHandleRxDataFrame(
 	if (pHeader->FC.Order)
 	{
 #ifdef AGGREGATION_SUPPORT
-		if ((pRxWI->PHYMODE < MODE_HTMIX) && (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_AGGREGATION_INUSED)))
+		if ((pRxWI->PHYMODE <= MODE_OFDM) && (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_AGGREGATION_INUSED)))
 		{
 			RX_BLK_SET_FLAG(pRxBlk, fRX_ARALINK);
 		}
 		else
 #endif
 		{
+#ifdef DOT11_N_SUPPORT
 			RX_BLK_SET_FLAG(pRxBlk, fRX_HTC);
 			// skip HTC contorl field
 			pRxBlk->pData += 4;
 			pRxBlk->DataSize -= 4;
+#endif // DOT11_N_SUPPORT //
 		}
 	}
 
@@ -470,10 +473,13 @@ VOID STAHandleRxDataFrame(
 		pRxBlk->pData += 2;
 	}
 
+#ifdef DOT11_N_SUPPORT
 	if (pRxD->BA)
 	{
 		RX_BLK_SET_FLAG(pRxBlk, fRX_AMPDU);
 	}
+#endif // DOT11_N_SUPPORT //
+
 
 	// 
 	// Case I  Process Broadcast & Multicast data frame
@@ -499,13 +505,32 @@ VOID STAHandleRxDataFrame(
 		}
 
 		Indicate_Legacy_Packet(pAd, pRxBlk, FromWhichBSSID);
-		DBGPRINT_RAW(RT_DEBUG_INFO, ("!!! report BCAST DATA to LLC (len=%d) !!!\n", pRxBlk->DataSize));
 		return;
 	}					
 	else if (pRxD->U2M)
 	{
 		pAd->LastRxRate = (USHORT)((pRxWI->MCS) + (pRxWI->BW <<7) + (pRxWI->ShortGI <<8)+ (pRxWI->PHYMODE <<14)) ;
 
+
+#ifdef QOS_DLS_SUPPORT
+        if (RX_BLK_TEST_FLAG(pRxBlk, fRX_DLS))
+		{
+			MAC_TABLE_ENTRY *pDlsEntry = NULL;
+
+			pDlsEntry = DlsEntryTableLookupByWcid(pAd, pRxWI->WirelessCliID, pHeader->Addr2, TRUE);
+										                        if(pDlsEntry)
+			Update_Rssi_Sample(pAd, &pDlsEntry->RssiSample, pRxWI);
+		}
+		else
+#endif // QOS_DLS_SUPPORT //
+		if (ADHOC_ON(pAd))
+		{
+			pEntry = MacTableLookup(pAd, pHeader->Addr2);
+			if (pEntry)
+				Update_Rssi_Sample(pAd, &pEntry->RssiSample, pRxWI);
+		}
+
+
 		Update_Rssi_Sample(pAd, &pAd->StaCfg.RssiSample, pRxWI);
 
 		pAd->StaCfg.LastSNR0 = (UCHAR)(pRxWI->SNR0);
@@ -567,6 +592,7 @@ VOID STAHandleRxMgmtFrame(
 
 	do
 	{
+
 		// We should collect RSSI not only U2M data but also my beacon
 		if ((pHeader->FC.SubType == SUBTYPE_BEACON) && (MAC_ADDR_EQUAL(&pAd->CommonCfg.Bssid, &pHeader->Addr2)))
 		{
@@ -594,21 +620,24 @@ VOID STAHandleRxControlFrame(
 	IN	PRTMP_ADAPTER	pAd,
 	IN	RX_BLK			*pRxBlk)
 {
+#ifdef DOT11_N_SUPPORT
 	PRXWI_STRUC		pRxWI = pRxBlk->pRxWI;
+#endif // DOT11_N_SUPPORT //
 	PHEADER_802_11	pHeader = pRxBlk->pHeader;
 	PNDIS_PACKET	pRxPacket = pRxBlk->pRxPacket;
 
 	switch (pHeader->FC.SubType)
 	{
 		case SUBTYPE_BLOCK_ACK_REQ:
+#ifdef DOT11_N_SUPPORT
 			{
 				CntlEnqueueForRecv(pAd, pRxWI->WirelessCliID, (pRxWI->MPDUtotalByteCount), (PFRAME_BA_REQ)pHeader);
 			}
 			break;
+#endif // DOT11_N_SUPPORT //
 		case SUBTYPE_BLOCK_ACK:
 		case SUBTYPE_ACK:
-		default:		
-			DBGPRINT(RT_DEBUG_INFO,("ignore CNTL (subtype=%d)\n", pHeader->FC.SubType));
+		default:
 			break;
 	}
 
@@ -635,7 +664,6 @@ VOID STAHandleRxControlFrame(
 		Need to consider QOS DATA format when converting to 802.3
 	========================================================================
 */
-
 BOOLEAN STARxDoneInterruptHandle(
 	IN	PRTMP_ADAPTER	pAd,
 	IN	BOOLEAN			argc)
@@ -800,7 +828,6 @@ BOOLEAN STARxDoneInterruptHandle(
 VOID	RTMPHandleTwakeupInterrupt(
 	IN PRTMP_ADAPTER pAd)
 {
-	DBGPRINT(RT_DEBUG_INFO, ("Twakeup Expired... !!!\n"));
 	AsicForceWakeup(pAd, FALSE);
 }
 
@@ -832,8 +859,7 @@ VOID STASendPackets(
 	PNDIS_PACKET	pPacket;
 	BOOLEAN			allowToSend = FALSE;
 
-	DBGPRINT(RT_DEBUG_INFO, ("====> STASendPackets\n"));
-	
+
 	for (Index = 0; Index < NumberOfPackets; Index++)
 	{
 		pPacket = ppPacketArray[Index];
@@ -935,8 +961,7 @@ NDIS_STATUS STASendPacket(
 		return NDIS_STATUS_FAILURE;
 	}
 
-	DBGPRINT(RT_DEBUG_LOUD,("RTMPSendPacket --> pSrcBufVA == %p, SrcBufLen=%d\n", pSrcBufVA, SrcBufLen));
-
+	
 	if (SrcBufLen < 14)
 	{
 		DBGPRINT(RT_DEBUG_ERROR,("STASendPacket --> Ndis Packet buffer error !!!\n"));
@@ -991,7 +1016,8 @@ NDIS_STATUS STASendPacket(
 		return NDIS_STATUS_FAILURE;
 	}
 
-	if (ADHOC_ON(pAd))
+	if (ADHOC_ON(pAd)
+		)
 	{
 		RTMP_SET_PACKET_WCID(pPacket, (UCHAR)pEntry->Aid);
 	}
@@ -1002,6 +1028,7 @@ NDIS_STATUS STASendPacket(
 	RTMPCheckEtherType(pAd, pPacket);
 
 	
+	
 	//
 	// WPA 802.1x secured port control - drop all non-802.1x frame before port secured
 	//
@@ -1040,8 +1067,10 @@ NDIS_STATUS STASendPacket(
 		NumberOfFrag = 1;	// Aggregation overwhelms fragmentation
 	else if (CLIENT_STATUS_TEST_FLAG(pEntry, fCLIENT_STATUS_AMSDU_INUSED))
 		NumberOfFrag = 1;	// Aggregation overwhelms fragmentation
+#ifdef DOT11_N_SUPPORT
 	else if ((pAd->StaCfg.HTPhyMode.field.MODE == MODE_HTMIX) || (pAd->StaCfg.HTPhyMode.field.MODE == MODE_HTGREENFIELD))
 		NumberOfFrag = 1;	// MIMO RATE overwhelms fragmentation
+#endif // DOT11_N_SUPPORT //
 	else
 	{
 		// The calculated "NumberOfFrag" is a rough estimation because of various 
@@ -1144,9 +1173,9 @@ NDIS_STATUS STASendPacket(
 	}
 	RTMP_IRQ_UNLOCK(&pAd->irq_lock, IrqFlags);
 
+#ifdef DOT11_N_SUPPORT
     if ((pAd->CommonCfg.BACapability.field.AutoBA == TRUE)&& 
-        (pAd->StaActive.SupportedPhyInfo.bHtEnable == TRUE) &&
-        INFRA_ON(pAd))
+        (pAd->StaActive.SupportedPhyInfo.bHtEnable == TRUE))
 	{
 		if (((pEntry->TXBAbitmap & (1<<UserPriority)) == 0) && 
             ((pEntry->BADeclineBitmap & (1<<UserPriority)) == 0) &&
@@ -1162,6 +1191,7 @@ NDIS_STATUS STASendPacket(
 			BAOriSessionSetUp(pAd, pEntry, 0, 0, 10, FALSE);
 		}
 	}
+#endif // DOT11_N_SUPPORT //
 
 	pAd->RalinkCounters.OneSecOsTxCount[QueIdx]++; // TODO: for debug only. to be removed
 	return NDIS_STATUS_SUCCESS;
@@ -1545,7 +1575,7 @@ VOID STABuildCommon802_11Header(
     	pHeader_802_11->FC.PwrMgmt = (pAd->StaCfg.Psm == PWR_SAVE);		
 }
 
-
+#ifdef DOT11_N_SUPPORT
 VOID STABuildCache802_11Header(
 	IN RTMP_ADAPTER		*pAd,
 	IN TX_BLK			*pTxBlk,
@@ -1595,7 +1625,10 @@ VOID STABuildCache802_11Header(
 		}
 		else
 #endif // QOS_DLS_SUPPORT //
-		COPY_MAC_ADDR(pHeader80211->Addr3, pTxBlk->pSrcBufHeader);
+		if (ADHOC_ON(pAd))
+			COPY_MAC_ADDR(pHeader80211->Addr3, pAd->CommonCfg.Bssid);
+		else
+			COPY_MAC_ADDR(pHeader80211->Addr3, pTxBlk->pSrcBufHeader);
 	}
 
 	// -----------------------------------------------------------------
@@ -1606,7 +1639,7 @@ VOID STABuildCache802_11Header(
 	else
     	pHeader80211->FC.PwrMgmt = (pAd->StaCfg.Psm == PWR_SAVE);	
 }
-
+#endif // DOT11_N_SUPPORT //
 
 static inline PUCHAR STA_Build_ARalink_Frame_Header(
 	IN RTMP_ADAPTER *pAd,
@@ -1666,7 +1699,7 @@ static inline PUCHAR STA_Build_ARalink_Frame_Header(
 	
 }
 
-
+#ifdef DOT11_N_SUPPORT
 static inline PUCHAR STA_Build_AMSDU_Frame_Header(
 	IN RTMP_ADAPTER *pAd,
 	IN TX_BLK		*pTxBlk)
@@ -1725,7 +1758,6 @@ VOID STA_AMPDU_Frame_Tx(
 	MAC_TABLE_ENTRY	*pMacEntry;
 	BOOLEAN			bVLANPkt;
 	PQUEUE_ENTRY	pQEntry;
-
 	
 	ASSERT(pTxBlk);
 
@@ -1757,6 +1789,7 @@ VOID STA_AMPDU_Frame_Tx(
 			pHeaderBufPtr = &pTxBlk->HeaderBuf[TXINFO_SIZE + TXWI_SIZE];
 		}
 
+
 		pHeader_802_11 = (HEADER_802_11 *) pHeaderBufPtr;
 		
 		// skip common header
@@ -1812,18 +1845,22 @@ VOID STA_AMPDU_Frame_Tx(
 		pHeaderBufPtr = (PCHAR) ROUND_UP(pHeaderBufPtr, 4);
 		pTxBlk->HdrPadLen = (ULONG)(pHeaderBufPtr - pTxBlk->HdrPadLen);
 
-		//
-		// Insert LLC-SNAP encapsulation - 8 octets
-		//
-		EXTRA_LLCSNAP_ENCAP_FROM_PKT_OFFSET(pTxBlk->pSrcBufData-2, pTxBlk->pExtraLlcSnapEncap);
-		if (pTxBlk->pExtraLlcSnapEncap)
 		{
-			NdisMoveMemory(pHeaderBufPtr, pTxBlk->pExtraLlcSnapEncap, 6);
-			pHeaderBufPtr += 6;
-			// get 2 octets (TypeofLen)
-			NdisMoveMemory(pHeaderBufPtr, pTxBlk->pSrcBufData-2, 2);
-			pHeaderBufPtr += 2;
-			pTxBlk->MpduHeaderLen += LENGTH_802_1_H;
+
+			//
+			// Insert LLC-SNAP encapsulation - 8 octets
+			//
+			EXTRA_LLCSNAP_ENCAP_FROM_PKT_OFFSET(pTxBlk->pSrcBufData-2, pTxBlk->pExtraLlcSnapEncap);
+			if (pTxBlk->pExtraLlcSnapEncap)
+			{
+				NdisMoveMemory(pHeaderBufPtr, pTxBlk->pExtraLlcSnapEncap, 6);
+				pHeaderBufPtr += 6;
+				// get 2 octets (TypeofLen)
+				NdisMoveMemory(pHeaderBufPtr, pTxBlk->pSrcBufData-2, 2);
+				pHeaderBufPtr += 2;
+				pTxBlk->MpduHeaderLen += LENGTH_802_1_H;
+			}
+
 		}
 
 		if (pMacEntry->isCached)
@@ -1984,7 +2021,7 @@ VOID STA_AMSDU_Frame_Tx(
 	// 
 	HAL_KickOutTx(pAd, pTxBlk, pTxBlk->QueIdx);
 }
-
+#endif // DOT11_N_SUPPORT //
 
 VOID STA_Legacy_Frame_Tx(
 	IN	PRTMP_ADAPTER	pAd,
@@ -1995,7 +2032,6 @@ VOID STA_Legacy_Frame_Tx(
 	USHORT			FreeNumber;
 	BOOLEAN			bVLANPkt;
 	PQUEUE_ENTRY	pQEntry;
-
 	
 	ASSERT(pTxBlk);
 
@@ -2026,6 +2062,7 @@ VOID STA_Legacy_Frame_Tx(
 	STAFindCipherAlgorithm(pAd, pTxBlk);
 	STABuildCommon802_11Header(pAd, pTxBlk);
 
+
 	// skip 802.3 header
 	pTxBlk->pSrcBufData = pTxBlk->pSrcBufHeader + LENGTH_802_3;
 	pTxBlk->SrcBufLen  -= LENGTH_802_3;
@@ -2054,34 +2091,35 @@ VOID STA_Legacy_Frame_Tx(
 		pTxBlk->MpduHeaderLen += 2;
 	}
 
-	//
-	// padding at front of LLC header
-	// LLC header should locate at 4-octets aligment
-	// 
+	// The remaining content of MPDU header should locate at 4-octets aligment	
 	pTxBlk->HdrPadLen = (ULONG)pHeaderBufPtr;
 	pHeaderBufPtr = (PCHAR) ROUND_UP(pHeaderBufPtr, 4);
 	pTxBlk->HdrPadLen = (ULONG)(pHeaderBufPtr - pTxBlk->HdrPadLen);
 
-	//
-	// Insert LLC-SNAP encapsulation - 8 octets
-	// 
-		//
-   	// if original Ethernet frame contains no LLC/SNAP, 
-	// then an extra LLC/SNAP encap is required 
-	//
-	EXTRA_LLCSNAP_ENCAP_FROM_PKT_START(pTxBlk->pSrcBufHeader, pTxBlk->pExtraLlcSnapEncap);
-	if (pTxBlk->pExtraLlcSnapEncap)
 	{
-		UCHAR vlan_size;
 
-		NdisMoveMemory(pHeaderBufPtr, pTxBlk->pExtraLlcSnapEncap, 6);
-		pHeaderBufPtr += 6;
-		// skip vlan tag
-		vlan_size =  (bVLANPkt) ? LENGTH_802_1Q : 0;
-		// get 2 octets (TypeofLen)
-		NdisMoveMemory(pHeaderBufPtr, pTxBlk->pSrcBufHeader+12+vlan_size, 2);
-		pHeaderBufPtr += 2;
-		pTxBlk->MpduHeaderLen += LENGTH_802_1_H;
+		//
+		// Insert LLC-SNAP encapsulation - 8 octets
+		// 
+		//
+   		// if original Ethernet frame contains no LLC/SNAP, 
+		// then an extra LLC/SNAP encap is required 
+		//
+		EXTRA_LLCSNAP_ENCAP_FROM_PKT_START(pTxBlk->pSrcBufHeader, pTxBlk->pExtraLlcSnapEncap);
+		if (pTxBlk->pExtraLlcSnapEncap)
+		{
+			UCHAR vlan_size;
+	
+			NdisMoveMemory(pHeaderBufPtr, pTxBlk->pExtraLlcSnapEncap, 6);
+			pHeaderBufPtr += 6;
+			// skip vlan tag
+			vlan_size =  (bVLANPkt) ? LENGTH_802_1Q : 0;
+			// get 2 octets (TypeofLen)
+			NdisMoveMemory(pHeaderBufPtr, pTxBlk->pSrcBufHeader+12+vlan_size, 2);
+			pHeaderBufPtr += 2;
+			pTxBlk->MpduHeaderLen += LENGTH_802_1_H;
+		}
+
 	}
 
 	//
@@ -2157,6 +2195,7 @@ VOID STA_ARalink_Frame_Tx(
 			//	will be updated after final frame was handled.
 			RTMPWriteTxWI_Data(pAd, (PTXWI_STRUC)(&pTxBlk->HeaderBuf[TXINFO_SIZE]), pTxBlk);
 
+
 			//
 			// Insert LLC-SNAP encapsulation - 8 octets
 			// 
@@ -2295,6 +2334,8 @@ VOID STA_Fragment_Frame_Tx(
 	pHeaderBufPtr = (PCHAR) ROUND_UP(pHeaderBufPtr, 4);
 	pTxBlk->HdrPadLen = (ULONG)(pHeaderBufPtr - pTxBlk->HdrPadLen);
 
+
+
 	//
 	// Insert LLC-SNAP encapsulation - 8 octets
 	// 
@@ -2467,7 +2508,7 @@ NDIS_STATUS STAHardTransmit(
 
 	pPacket = QUEUE_ENTRY_TO_PACKET(pTxBlk->TxPacketList.Head);
 
-#ifdef CARRIER_DETECTION_SUPPORT // Roger sync Carrier
+#if 0 //def CARRIER_DETECTION_SUPPORT // Roger sync Carrier
 		if ((pAd->CommonCfg.CarrierDetect.Enable == TRUE) && (isCarrierDetectExist(pAd) == TRUE))
 	{
 		DBGPRINT(RT_DEBUG_INFO,("STAHardTransmit --> radar detect not in normal mode !!!\n"));
@@ -2490,7 +2531,8 @@ NDIS_STATUS STAHardTransmit(
 	
 	// It should not change PSM bit, when APSD turn on.
 	if ((!(pAd->CommonCfg.bAPSDCapable && pAd->CommonCfg.APEdcaParm.bAPSDCapable) && (pAd->CommonCfg.bAPSDForcePowerSave == FALSE))
-		|| (RTMP_GET_PACKET_EAPOL(pTxBlk->pPacket)))
+		|| (RTMP_GET_PACKET_EAPOL(pTxBlk->pPacket))
+		|| (RTMP_GET_PACKET_WAI(pTxBlk->pPacket)))
 	{
 		if ((pAd->StaCfg.Psm == PWR_SAVE) &&
             (pAd->StaCfg.WindowsPowerMode == Ndis802_11PowerModeFast_PSP))
@@ -2499,12 +2541,14 @@ NDIS_STATUS STAHardTransmit(
 
 	switch (pTxBlk->TxFrameType)
 	{
+#ifdef DOT11_N_SUPPORT
 		case TX_AMPDU_FRAME:
 				STA_AMPDU_Frame_Tx(pAd, pTxBlk);
 			break;
 		case TX_AMSDU_FRAME:
 				STA_AMSDU_Frame_Tx(pAd, pTxBlk);
 			break;
+#endif // DOT11_N_SUPPORT //
 		case TX_LEGACY_FRAME:
 				STA_Legacy_Frame_Tx(pAd, pTxBlk);
 			break;
@@ -2556,6 +2600,15 @@ VOID Sta_Announce_or_Forward_802_3_Packet(
 	IN	PNDIS_PACKET	pPacket,
 	IN	UCHAR			FromWhichBSSID)
 {
-	announce_802_3_packet(pAd, pPacket);
+	if (TRUE
+		)
+	{
+		announce_802_3_packet(pAd, pPacket);
+	}
+	else
+	{
+		// release packet
+		RELEASE_NDIS_PACKET(pAd, pPacket, NDIS_STATUS_FAILURE);
+	}
 }
 
