@@ -160,7 +160,6 @@ BOOLEAN	WpaMsgTypeSubst(
 			*MsgType = MT2_EAPOLASFAlert;
 			break;
 		default:
-			DBGPRINT(RT_DEBUG_INFO, ("WpaMsgTypeSubst : return FALSE; \n"));	   
 			return FALSE;		
 	}	
 	return TRUE;
@@ -221,19 +220,6 @@ VOID WpaEAPOLKeyAction(
 
 	*((USHORT *)&peerKeyInfo) = cpu2le16(*((USHORT *)&peerKeyInfo));
 
-	// Sanity check, this should only happen in WPA(2)-PSK mode
-	// 0. Debug print all bit information
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Key Description Version %d\n", peerKeyInfo.KeyDescVer));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Key Type %d\n", peerKeyInfo.KeyType));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Key Index %d\n", peerKeyInfo.KeyIndex));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Install %d\n", peerKeyInfo.Install));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Key Ack %d\n", peerKeyInfo.KeyAck));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Key MIC %d\n", peerKeyInfo.KeyMic));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Secure %d\n", peerKeyInfo.Secure));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Error %d\n", peerKeyInfo.Error));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo Request %d\n", peerKeyInfo.Request));
-	DBGPRINT(RT_DEBUG_INFO, ("KeyInfo EKD_DL %d\n", peerKeyInfo.EKD_DL));
-
 
 	// 1. Check EAPOL frame version and type
 	EapolVr	= (UCHAR) Elem->Msg[LENGTH_802_11+LENGTH_802_1_H];
@@ -506,10 +492,6 @@ VOID	WpaPairMsg1Action(
 	// Save key to PTK entry
 	NdisMoveMemory(pAd->StaCfg.PTK, PTK, LEN_PTK);
 
-
-	// Construct Msg 2
-	pAd->Sequence = ((pAd->Sequence) + 1) & (MAX_SEQ_NUMBER);
-
 	// init 802.3 header and Fill Packet
 	MAKE_802_3_HEADER(Header802_3, pAd->CommonCfg.Bssid, pAd->CurrentAddress, EAPOL);	
 
@@ -662,9 +644,6 @@ VOID Wpa2PairMsg1Action(
 	// Save key to PTK entry
 	NdisMoveMemory(pAd->StaCfg.PTK, PTK, LEN_PTK);
 
-	// Construct Msg 2
-	pAd->Sequence = ((pAd->Sequence) + 1) & (MAX_SEQ_NUMBER);
-
 	// init 802.3 header and Fill Packet
 	MAKE_802_3_HEADER(Header802_3, pAd->CommonCfg.Bssid, pAd->CurrentAddress, EAPOL);	
 
@@ -866,9 +845,6 @@ VOID	WpaPairMsg3Action(
 	if(!NdisEqualMemory(pAd->StaCfg.ANonce, pMsg3->KeyDesc.KeyNonce, LEN_KEY_DESC_NONCE))
 		return;
 
-	// 5. Construct Message 4
-	pAd->Sequence = ((pAd->Sequence) + 1) & (MAX_SEQ_NUMBER);
-
 	// init 802.3 header and Fill Packet
 	MAKE_802_3_HEADER(Header802_3, pAd->CommonCfg.Bssid, pAd->CurrentAddress, EAPOL);	
 
@@ -1126,10 +1102,6 @@ VOID    Wpa2PairMsg3Action(
 							  pAd->SharedKey[BSS0][pAd->StaCfg.DefaultKeyId].CipherAlg, 
 							  NULL);
 
-
-	// 6. Construct Message 4
-	pAd->Sequence = ((pAd->Sequence) + 1) & (MAX_SEQ_NUMBER);
-
 	// init 802.3 header and Fill Packet
 	MAKE_802_3_HEADER(Header802_3, pAd->CommonCfg.Bssid, pAd->CurrentAddress, EAPOL);
 
@@ -1438,9 +1410,6 @@ VOID	WpaGroupMsg1Action(
     // Indicate Connected for GUI
     pAd->IndicateMediaState = NdisMediaStateConnected;
 
-	// 4. Construct Group Message 2
-	pAd->Sequence = ((pAd->Sequence) + 1) & (MAX_SEQ_NUMBER);
-
 	// init header and Fill Packet
 	MAKE_802_3_HEADER(Header802_3, pAd->CommonCfg.Bssid, pAd->CurrentAddress, EAPOL);		
 
@@ -1766,10 +1735,6 @@ BOOLEAN ParseKeyData(
 	if (KeyDataLength >= 8)
     {
         pKDE = (PKDE_ENCAP) pMyKeyData;
-        DBGPRINT(RT_DEBUG_INFO, ("pKDE->Type %x \n", pKDE->Type));
-        DBGPRINT(RT_DEBUG_INFO, ("pKDE->Len 0x%x \n", pKDE->Len));
-        DBGPRINT(RT_DEBUG_INFO, ("pKDE->OUI %x %x %x \n", pKDE->OUI[0],pKDE->OUI[1],pKDE->OUI[2]));
-    	DBGPRINT(RT_DEBUG_INFO, ("pKDE->DataType %x \n", pKDE->DataType));
     }
 	else
     {
